
module Make

# 5 "src/parser/grammar.mly"
           ( C : Parser_config.ParseFile )
# 7 "src/parser/grammar.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error of int
    
    let _eRR =
      fun _s ->
        raise (Error _s)
    
    type token = Elpi_lexer_config.Tokens.token
    
  end
  
  include MenhirBasics
  
# 7 "src/parser/grammar.mly"
  
open Elpi_util
open Elpi_lexer_config

open Lexer_config
open Parser_config
open Ast
open Term


let loc (startpos, endpos) = {
  Util.Loc.source_name = startpos.Lexing.pos_fname;
  source_start = startpos.Lexing.pos_cnum;
  source_stop = endpos.Lexing.pos_cnum;
  line = startpos.Lexing.pos_lnum;
  line_starts_at = startpos.Lexing.pos_bol;
}

let desugar_multi_binder loc = function
  | App(Const hd as binder,args)
    when Func.equal hd Func.pif || Func.equal hd Func.sigmaf && List.length args > 1 ->
      let last, rev_rest = let l = List.rev args in List.hd l, List.tl l in
      let () = match last with
        | Lam _ -> ()
        | Const x when Func.is_uvar_name x -> ()
        | _ -> raise (ParseError(loc,"The last argument of 'pi' or 'sigma' must be a function or a unification variable, while it is: " ^ Ast.Term.show last)) in
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
            raise (ParseError(loc,"Only names are allowed after 'pi' or 'sigma'"))) rev_rest in
      let body = mkApp loc [binder;last] in
      List.fold_left (fun bo name -> mkApp loc [binder;mkLam name bo]) body names
  | (App _ | Const _ | Lam _ | CData _ | Quoted _) as t -> t
;;

let desugar_macro loc lhs rhs =
  match lhs, rhs with
  | Const name, body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      name, body
  | App(Const name,args), body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
              raise (ParseError(loc,"Macro parameters must be names"))) args in
      name, List.fold_right mkLam names body
  | _ ->
        raise (ParseError(loc,"Illformed macro left hand side"))
;;

let mkApp loc = function
  | Const c :: a :: App (Const c1, args) :: [] when Func.(equal c andf && equal c1 andf) ->
      mkAppF loc c (a :: args)
  | l -> mkApp loc l

let binder l = function
  | None -> l
  | Some (loc,b) ->
      match List.rev l with
      | Const name :: rest ->
          List.rev rest @ [mkLam (Func.show name) b]
      | _ -> raise (ParseError(loc,"bind '\\' operator must follow a name"))
;;

let underscore () = Const Func.dummyname

let decode_sequent t =
  match t with
  | App(Const c,[hyps;bo]) when c == Func.sequentf -> hyps, bo
  | _ -> underscore (), t

let prop = Func.from_string "prop"

let fix_church x = if Func.show x = "o" then prop else x

let mode_of_IO io =
  if io = 'i' then true
  else if io = 'o' then false
  else assert false


# 110 "src/parser/grammar.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_goal) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: goal. *)

    | MenhirState008 : (('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_state
      (** State 008.
        Stack shape : LPAREN.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LCURLY, 'r) _menhir_state
      (** State 018.
        Stack shape : LCURLY.
        Start symbol: <undetermined>. *)

    | MenhirState019 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 019.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState021 : (('s, 'r) _menhir_cell1_PIPE, 'r) _menhir_state
      (** State 021.
        Stack shape : PIPE.
        Start symbol: <undetermined>. *)

    | MenhirState028 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 028.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState036 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 036.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState037 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 037.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState038 : (('s, 'r) _menhir_cell1_BIND, 'r) _menhir_state
      (** State 038.
        Stack shape : BIND.
        Start symbol: <undetermined>. *)

    | MenhirState039 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 039.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState043 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 043.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState044 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 044.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState049 : (('s, 'r) _menhir_cell1_closed_term, 'r) _menhir_state
      (** State 049.
        Stack shape : closed_term.
        Start symbol: <undetermined>. *)

    | MenhirState051 : (('s, 'r) _menhir_cell1_constant, 'r) _menhir_state
      (** State 051.
        Stack shape : constant.
        Start symbol: <undetermined>. *)

    | MenhirState056 : (('s, 'r) _menhir_cell1_term _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 056.
        Stack shape : term VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState058 : (('s, 'r) _menhir_cell1_term _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 058.
        Stack shape : term SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState060 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 060.
        Stack shape : term FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState062 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 062.
        Stack shape : term FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState064 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 064.
        Stack shape : term FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState066 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 066.
        Stack shape : term FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState068 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 068.
        Stack shape : term FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState070 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 070.
        Stack shape : term FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState072 : (('s, 'r) _menhir_cell1_term _menhir_cell0_OR, 'r) _menhir_state
      (** State 072.
        Stack shape : term OR.
        Start symbol: <undetermined>. *)

    | MenhirState074 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MOD, 'r) _menhir_state
      (** State 074.
        Stack shape : term MOD.
        Start symbol: <undetermined>. *)

    | MenhirState076 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 076.
        Stack shape : term MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState078 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 078.
        Stack shape : term FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState080 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DIV, 'r) _menhir_state
      (** State 080.
        Stack shape : term DIV.
        Start symbol: <undetermined>. *)

    | MenhirState082 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 082.
        Stack shape : term MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState084 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 084.
        Stack shape : term MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState086 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 086.
        Stack shape : term MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState088 : (('s, 'r) _menhir_cell1_term _menhir_cell0_IS, 'r) _menhir_state
      (** State 088.
        Stack shape : term IS.
        Start symbol: <undetermined>. *)

    | MenhirState090 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 090.
        Stack shape : term FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState092 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 092.
        Stack shape : term FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState094 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 094.
        Stack shape : term FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState096 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONS, 'r) _menhir_state
      (** State 096.
        Stack shape : term CONS.
        Start symbol: <undetermined>. *)

    | MenhirState098 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 098.
        Stack shape : term FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState100 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 100.
        Stack shape : term FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState102 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 102.
        Stack shape : term EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState104 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ, 'r) _menhir_state
      (** State 104.
        Stack shape : term EQ.
        Start symbol: <undetermined>. *)

    | MenhirState106 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 106.
        Stack shape : term DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState108 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 108.
        Stack shape : term CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState110 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 110.
        Stack shape : term CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState112 : (('s, 'r) _menhir_cell1_term _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 112.
        Stack shape : term ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState114 : (('s, 'r) _menhir_cell1_term _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 114.
        Stack shape : term QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState118 : (('s, 'r) _menhir_cell1_constant _menhir_cell0_BIND, 'r) _menhir_state
      (** State 118.
        Stack shape : constant BIND.
        Start symbol: <undetermined>. *)

    | MenhirState123 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 123.
        Stack shape : term_noconj VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState125 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 125.
        Stack shape : term_noconj SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState127 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 127.
        Stack shape : term_noconj FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState129 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 129.
        Stack shape : term_noconj FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState131 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 131.
        Stack shape : term_noconj FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState133 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 133.
        Stack shape : term_noconj FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState135 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 135.
        Stack shape : term_noconj FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState137 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 137.
        Stack shape : term_noconj FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState139 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_OR, 'r) _menhir_state
      (** State 139.
        Stack shape : term_noconj OR.
        Start symbol: <undetermined>. *)

    | MenhirState141 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MOD, 'r) _menhir_state
      (** State 141.
        Stack shape : term_noconj MOD.
        Start symbol: <undetermined>. *)

    | MenhirState143 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 143.
        Stack shape : term_noconj MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState145 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 145.
        Stack shape : term_noconj FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState147 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DIV, 'r) _menhir_state
      (** State 147.
        Stack shape : term_noconj DIV.
        Start symbol: <undetermined>. *)

    | MenhirState149 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 149.
        Stack shape : term_noconj MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState151 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 151.
        Stack shape : term_noconj MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState153 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 153.
        Stack shape : term_noconj MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState155 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_IS, 'r) _menhir_state
      (** State 155.
        Stack shape : term_noconj IS.
        Start symbol: <undetermined>. *)

    | MenhirState157 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 157.
        Stack shape : term_noconj FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState159 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 159.
        Stack shape : term_noconj FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState161 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 161.
        Stack shape : term_noconj FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState163 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONS, 'r) _menhir_state
      (** State 163.
        Stack shape : term_noconj CONS.
        Start symbol: <undetermined>. *)

    | MenhirState165 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 165.
        Stack shape : term_noconj FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState167 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 167.
        Stack shape : term_noconj FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState169 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 169.
        Stack shape : term_noconj EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState171 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ, 'r) _menhir_state
      (** State 171.
        Stack shape : term_noconj EQ.
        Start symbol: <undetermined>. *)

    | MenhirState173 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 173.
        Stack shape : term_noconj DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState175 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 175.
        Stack shape : term_noconj CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState177 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 177.
        Stack shape : term_noconj ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState180 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 180.
        Stack shape : term_noconj QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState184 : (('s, 'r) _menhir_cell1_term_noconj, 'r) _menhir_state
      (** State 184.
        Stack shape : term_noconj.
        Start symbol: <undetermined>. *)

    | MenhirState187 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 187.
        Stack shape : term_noconj CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState196 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 196.
        Stack shape : LPAREN FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState221 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_term, 'r) _menhir_state
      (** State 221.
        Stack shape : LPAREN term.
        Start symbol: <undetermined>. *)

    | MenhirState268 : ('s, _menhir_box_program) _menhir_state
      (** State 268.
        Stack shape : .
        Start symbol: program. *)

    | MenhirState270 : (('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_state
      (** State 270.
        Stack shape : USEONLY.
        Start symbol: program. *)

    | MenhirState271 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 271.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState273 : ((('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 273.
        Stack shape : USEONLY separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState274 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 274.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState277 : (('s, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 277.
        Stack shape : type_term ARROW.
        Start symbol: program. *)

    | MenhirState279 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 279.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState281 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 281.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState286 : (('s, _menhir_box_program) _menhir_cell1_atype_term, _menhir_box_program) _menhir_state
      (** State 286.
        Stack shape : atype_term.
        Start symbol: program. *)

    | MenhirState290 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 290.
        Stack shape : constant CONJ.
        Start symbol: program. *)

    | MenhirState292 : (('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_state
      (** State 292.
        Stack shape : TYPEABBREV.
        Start symbol: program. *)

    | MenhirState293 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 293.
        Stack shape : TYPEABBREV LPAREN.
        Start symbol: program. *)

    | MenhirState294 : (((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 294.
        Stack shape : TYPEABBREV LPAREN constant.
        Start symbol: program. *)

    | MenhirState297 : ((('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 297.
        Stack shape : constant constant.
        Start symbol: program. *)

    | MenhirState300 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform, _menhir_box_program) _menhir_state
      (** State 300.
        Stack shape : TYPEABBREV abbrevform.
        Start symbol: program. *)

    | MenhirState302 : (('s, _menhir_box_program) _menhir_cell1_SIG, _menhir_box_program) _menhir_state
      (** State 302.
        Stack shape : SIG.
        Start symbol: program. *)

    | MenhirState304 : (('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_state
      (** State 304.
        Stack shape : SHORTEN.
        Start symbol: program. *)

    | MenhirState310 : ((('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 310.
        Stack shape : SHORTEN constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState312 : (('s, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 312.
        Stack shape : subtrie CONJ.
        Start symbol: program. *)

    | MenhirState316 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 316.
        Stack shape : constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState322 : (('s, _menhir_box_program) _menhir_cell1_NAMESPACE, _menhir_box_program) _menhir_state
      (** State 322.
        Stack shape : NAMESPACE.
        Start symbol: program. *)

    | MenhirState325 : (('s, _menhir_box_program) _menhir_cell1_MODULE, _menhir_box_program) _menhir_state
      (** State 325.
        Stack shape : MODULE.
        Start symbol: program. *)

    | MenhirState328 : (('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 328.
        Stack shape : MODE LPAREN.
        Start symbol: program. *)

    | MenhirState329 : ((('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 329.
        Stack shape : MODE LPAREN constant.
        Start symbol: program. *)

    | MenhirState333 : (('s, _menhir_box_program) _menhir_cell1_i_o, _menhir_box_program) _menhir_state
      (** State 333.
        Stack shape : i_o.
        Start symbol: program. *)

    | MenhirState335 : (('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_state
      (** State 335.
        Stack shape : MACRO.
        Start symbol: program. *)

    | MenhirState337 : ((('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 337.
        Stack shape : MACRO term VDASH.
        Start symbol: program. *)

    | MenhirState339 : (('s, _menhir_box_program) _menhir_cell1_LOCALKIND, _menhir_box_program) _menhir_state
      (** State 339.
        Stack shape : LOCALKIND.
        Start symbol: program. *)

    | MenhirState341 : (('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_state
      (** State 341.
        Stack shape : LOCAL.
        Start symbol: program. *)

    | MenhirState342 : ((('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 342.
        Stack shape : LOCAL separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState347 : (('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_state
      (** State 347.
        Stack shape : KIND.
        Start symbol: program. *)

    | MenhirState348 : ((('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 348.
        Stack shape : KIND separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState350 : (('s, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 350.
        Stack shape : TYPE ARROW.
        Start symbol: program. *)

    | MenhirState354 : (('s, _menhir_box_program) _menhir_cell1_FIXITY, _menhir_box_program) _menhir_state
      (** State 354.
        Stack shape : FIXITY.
        Start symbol: program. *)

    | MenhirState360 : (('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_state
      (** State 360.
        Stack shape : EXPORTDEF.
        Start symbol: program. *)

    | MenhirState361 : ((('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 361.
        Stack shape : EXPORTDEF separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState364 : (('s, _menhir_box_program) _menhir_cell1_CONSTRAINT, _menhir_box_program) _menhir_state
      (** State 364.
        Stack shape : CONSTRAINT.
        Start symbol: program. *)

    | MenhirState366 : ((('s, _menhir_box_program) _menhir_cell1_CONSTRAINT, _menhir_box_program) _menhir_cell1_list_constant_ _menhir_cell0_QDASH, _menhir_box_program) _menhir_state
      (** State 366.
        Stack shape : CONSTRAINT list(constant) QDASH.
        Start symbol: program. *)

    | MenhirState369 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 369.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState372 : (('s, _menhir_box_program) _menhir_cell1_COLON, _menhir_box_program) _menhir_state
      (** State 372.
        Stack shape : COLON.
        Start symbol: program. *)

    | MenhirState378 : (('s, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 378.
        Stack shape : INDEX LPAREN.
        Start symbol: program. *)

    | MenhirState385 : (('s, _menhir_box_program) _menhir_cell1_indexing, _menhir_box_program) _menhir_state
      (** State 385.
        Stack shape : indexing.
        Start symbol: program. *)

    | MenhirState396 : (('s, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON, _menhir_box_program) _menhir_state
      (** State 396.
        Stack shape : attribute COLON.
        Start symbol: program. *)

    | MenhirState398 : (('s, _menhir_box_program) _menhir_cell1_CLOSED, _menhir_box_program) _menhir_state
      (** State 398.
        Stack shape : CLOSED.
        Start symbol: program. *)

    | MenhirState419 : (('s, _menhir_box_program) _menhir_cell1_decl, _menhir_box_program) _menhir_state
      (** State 419.
        Stack shape : decl.
        Start symbol: program. *)

    | MenhirState425 : (('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_state
      (** State 425.
        Stack shape : attributes.
        Start symbol: program. *)

    | MenhirState426 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_state
      (** State 426.
        Stack shape : attributes TYPE.
        Start symbol: program. *)

    | MenhirState427 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 427.
        Stack shape : attributes TYPE separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState429 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_state
      (** State 429.
        Stack shape : attributes RULE.
        Start symbol: program. *)

    | MenhirState430 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 430.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState432 : ((('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_closed_term _menhir_cell0_COLON, _menhir_box_program) _menhir_state
      (** State 432.
        Stack shape : LPAREN closed_term COLON.
        Start symbol: program. *)

    | MenhirState435 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 435.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState439 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND, _menhir_box_program) _menhir_state
      (** State 439.
        Stack shape : attributes RULE list(sequent) BIND.
        Start symbol: program. *)

    | MenhirState440 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 440.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState444 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___, _menhir_box_program) _menhir_state
      (** State 444.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))).
        Start symbol: program. *)

    | MenhirState447 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__, _menhir_box_program) _menhir_state
      (** State 447.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))) option(preceded(PIPE,term)).
        Start symbol: program. *)

    | MenhirState450 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_state
      (** State 450.
        Stack shape : attributes PRED.
        Start symbol: program. *)

    | MenhirState451 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 451.
        Stack shape : attributes PRED constant.
        Start symbol: program. *)

    | MenhirState452 : (('s, _menhir_box_program) _menhir_cell1_IO_COLON, _menhir_box_program) _menhir_state
      (** State 452.
        Stack shape : IO_COLON.
        Start symbol: program. *)

    | MenhirState457 : (('s, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_, _menhir_box_program) _menhir_state
      (** State 457.
        Stack shape : pred_item option(CONJ).
        Start symbol: program. *)

    | MenhirState460 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 460.
        Stack shape : attributes LPAREN.
        Start symbol: program. *)

    | MenhirState463 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE, _menhir_box_program) _menhir_state
      (** State 463.
        Stack shape : attributes FAMILY_TILDE.
        Start symbol: program. *)

    | MenhirState465 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_state
      (** State 465.
        Stack shape : attributes head_term.
        Start symbol: program. *)

    | MenhirState466 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_, _menhir_box_program) _menhir_state
      (** State 466.
        Stack shape : attributes head_term nonempty_list(closed_term).
        Start symbol: program. *)

    | MenhirState470 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 470.
        Stack shape : attributes clause_hd_term VDASH.
        Start symbol: program. *)

    | MenhirState472 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH, _menhir_box_program) _menhir_state
      (** State 472.
        Stack shape : attributes clause_hd_term SLASH.
        Start symbol: program. *)

    | MenhirState474 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH, _menhir_box_program) _menhir_state
      (** State 474.
        Stack shape : attributes clause_hd_term QDASH.
        Start symbol: program. *)

    | MenhirState476 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR, _menhir_box_program) _menhir_state
      (** State 476.
        Stack shape : attributes clause_hd_term OR.
        Start symbol: program. *)

    | MenhirState478 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD, _menhir_box_program) _menhir_state
      (** State 478.
        Stack shape : attributes clause_hd_term MOD.
        Start symbol: program. *)

    | MenhirState480 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs, _menhir_box_program) _menhir_state
      (** State 480.
        Stack shape : attributes clause_hd_term MINUSs.
        Start symbol: program. *)

    | MenhirState482 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr, _menhir_box_program) _menhir_state
      (** State 482.
        Stack shape : attributes clause_hd_term MINUSr.
        Start symbol: program. *)

    | MenhirState484 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi, _menhir_box_program) _menhir_state
      (** State 484.
        Stack shape : attributes clause_hd_term MINUSi.
        Start symbol: program. *)

    | MenhirState486 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS, _menhir_box_program) _menhir_state
      (** State 486.
        Stack shape : attributes clause_hd_term MINUS.
        Start symbol: program. *)

    | MenhirState488 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS, _menhir_box_program) _menhir_state
      (** State 488.
        Stack shape : attributes clause_hd_term IS.
        Start symbol: program. *)

    | MenhirState490 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES, _menhir_box_program) _menhir_state
      (** State 490.
        Stack shape : attributes clause_hd_term FAMILY_TIMES.
        Start symbol: program. *)

    | MenhirState492 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK, _menhir_box_program) _menhir_state
      (** State 492.
        Stack shape : attributes clause_hd_term FAMILY_TICK.
        Start symbol: program. *)

    | MenhirState494 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP, _menhir_box_program) _menhir_state
      (** State 494.
        Stack shape : attributes clause_hd_term FAMILY_SHARP.
        Start symbol: program. *)

    | MenhirState497 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS, _menhir_box_program) _menhir_state
      (** State 497.
        Stack shape : attributes clause_hd_term FAMILY_PLUS.
        Start symbol: program. *)

    | MenhirState499 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR, _menhir_box_program) _menhir_state
      (** State 499.
        Stack shape : attributes clause_hd_term FAMILY_OR.
        Start symbol: program. *)

    | MenhirState501 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS, _menhir_box_program) _menhir_state
      (** State 501.
        Stack shape : attributes clause_hd_term FAMILY_MINUS.
        Start symbol: program. *)

    | MenhirState503 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT, _menhir_box_program) _menhir_state
      (** State 503.
        Stack shape : attributes clause_hd_term FAMILY_LT.
        Start symbol: program. *)

    | MenhirState505 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT, _menhir_box_program) _menhir_state
      (** State 505.
        Stack shape : attributes clause_hd_term FAMILY_GT.
        Start symbol: program. *)

    | MenhirState507 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP, _menhir_box_program) _menhir_state
      (** State 507.
        Stack shape : attributes clause_hd_term FAMILY_EXP.
        Start symbol: program. *)

    | MenhirState509 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ, _menhir_box_program) _menhir_state
      (** State 509.
        Stack shape : attributes clause_hd_term FAMILY_EQ.
        Start symbol: program. *)

    | MenhirState511 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK, _menhir_box_program) _menhir_state
      (** State 511.
        Stack shape : attributes clause_hd_term FAMILY_BTICK.
        Start symbol: program. *)

    | MenhirState513 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND, _menhir_box_program) _menhir_state
      (** State 513.
        Stack shape : attributes clause_hd_term FAMILY_AND.
        Start symbol: program. *)

    | MenhirState515 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2, _menhir_box_program) _menhir_state
      (** State 515.
        Stack shape : attributes clause_hd_term EQ2.
        Start symbol: program. *)

    | MenhirState517 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ, _menhir_box_program) _menhir_state
      (** State 517.
        Stack shape : attributes clause_hd_term EQ.
        Start symbol: program. *)

    | MenhirState519 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV, _menhir_box_program) _menhir_state
      (** State 519.
        Stack shape : attributes clause_hd_term DIV.
        Start symbol: program. *)

    | MenhirState521 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW, _menhir_box_program) _menhir_state
      (** State 521.
        Stack shape : attributes clause_hd_term DARROW.
        Start symbol: program. *)

    | MenhirState523 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS, _menhir_box_program) _menhir_state
      (** State 523.
        Stack shape : attributes clause_hd_term CONS.
        Start symbol: program. *)

    | MenhirState525 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2, _menhir_box_program) _menhir_state
      (** State 525.
        Stack shape : attributes clause_hd_term CONJ2.
        Start symbol: program. *)

    | MenhirState527 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 527.
        Stack shape : attributes clause_hd_term CONJ.
        Start symbol: program. *)

    | MenhirState529 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 529.
        Stack shape : attributes clause_hd_term ARROW.
        Start symbol: program. *)

    | MenhirState533 : (('s, _menhir_box_program) _menhir_cell1_accumulate, _menhir_box_program) _menhir_state
      (** State 533.
        Stack shape : accumulate.
        Start symbol: program. *)

    | MenhirState538 : (('s, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 538.
        Stack shape : filename CONJ.
        Start symbol: program. *)

  
  and ('s, 'r) _menhir_cell1_abbrevform = 
    | MenhirCell1_abbrevform of 's * ('s, 'r) _menhir_state * (Ast.Func.t * Ast.Func.t list)
  
  and ('s, 'r) _menhir_cell1_accumulate = 
    | MenhirCell1_accumulate of 's * ('s, 'r) _menhir_state * (string) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attribute = 
    | MenhirCell1_attribute of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attributes = 
    | MenhirCell1_attributes of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_atype_term = 
    | MenhirCell1_atype_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_clause_hd_term = 
    | MenhirCell1_clause_hd_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_closed_term = 
    | MenhirCell1_closed_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_constant = 
    | MenhirCell1_constant of 's * ('s, 'r) _menhir_state * (Ast.Func.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (Ast.Program.decl)
  
  and ('s, 'r) _menhir_cell1_filename = 
    | MenhirCell1_filename of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_head_term = 
    | MenhirCell1_head_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_i_o = 
    | MenhirCell1_i_o of 's * ('s, 'r) _menhir_state * (bool)
  
  and ('s, 'r) _menhir_cell1_indexing = 
    | MenhirCell1_indexing of 's * ('s, 'r) _menhir_state * (int)
  
  and ('s, 'r) _menhir_cell1_list_constant_ = 
    | MenhirCell1_list_constant_ of 's * ('s, 'r) _menhir_state * (Ast.Func.t list)
  
  and ('s, 'r) _menhir_cell1_list_sequent_ = 
    | MenhirCell1_list_sequent_ of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_closed_term_ = 
    | MenhirCell1_nonempty_list_closed_term_ of 's * ('s, 'r) _menhir_state * (Ast.Term.t list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_indexing_ = 
    | MenhirCell1_nonempty_list_indexing_ of 's * ('s, 'r) _menhir_state * (int list)
  
  and 's _menhir_cell0_option_CONJ_ = 
    | MenhirCell0_option_CONJ_ of 's * (unit option)
  
  and 's _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ = 
    | MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ of 's * (Ast.Chr.sequent list option)
  
  and 's _menhir_cell0_option_preceded_PIPE_term__ = 
    | MenhirCell0_option_preceded_PIPE_term__ of 's * (Ast.Term.t option)
  
  and ('s, 'r) _menhir_cell1_pred_item = 
    | MenhirCell1_pred_item of 's * ('s, 'r) _menhir_state * (bool * Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_CONJ_constant_ = 
    | MenhirCell1_separated_nonempty_list_CONJ_constant_ of 's * ('s, 'r) _menhir_state * (Ast.Func.t list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_sequent = 
    | MenhirCell1_sequent of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_subtrie = 
    | MenhirCell1_subtrie of 's * ('s, 'r) _menhir_state * ((string * string) list)
  
  and ('s, 'r) _menhir_cell1_term = 
    | MenhirCell1_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_term_noconj = 
    | MenhirCell1_term_noconj of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_type_term = 
    | MenhirCell1_type_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_ARROW = 
    | MenhirCell0_ARROW of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BIND = 
    | MenhirCell1_BIND of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_BIND = 
    | MenhirCell0_BIND of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CLOSED = 
    | MenhirCell1_CLOSED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_COLON = 
    | MenhirCell0_COLON of 's * Lexing.position
  
  and 's _menhir_cell0_CONJ = 
    | MenhirCell0_CONJ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONJ2 = 
    | MenhirCell0_CONJ2 of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONS = 
    | MenhirCell0_CONS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CONSTRAINT = 
    | MenhirCell1_CONSTRAINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_DARROW = 
    | MenhirCell0_DARROW of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_DIV = 
    | MenhirCell0_DIV of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ = 
    | MenhirCell0_EQ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ2 = 
    | MenhirCell0_EQ2 of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EXPORTDEF = 
    | MenhirCell1_EXPORTDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FAMILY_AND = 
    | MenhirCell0_FAMILY_AND of 's * (
# 85 "src/parser/tokens.mly"
       (string)
# 1114 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_BTICK = 
    | MenhirCell0_FAMILY_BTICK of 's * (
# 81 "src/parser/tokens.mly"
       (string)
# 1121 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EQ = 
    | MenhirCell0_FAMILY_EQ of 's * (
# 79 "src/parser/tokens.mly"
       (string)
# 1128 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EXP = 
    | MenhirCell0_FAMILY_EXP of 's * (
# 76 "src/parser/tokens.mly"
       (string)
# 1135 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_GT = 
    | MenhirCell0_FAMILY_GT of 's * (
# 78 "src/parser/tokens.mly"
       (string)
# 1142 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_LT = 
    | MenhirCell0_FAMILY_LT of 's * (
# 77 "src/parser/tokens.mly"
       (string)
# 1149 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_MINUS = 
    | MenhirCell0_FAMILY_MINUS of 's * (
# 75 "src/parser/tokens.mly"
       (string)
# 1156 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_OR = 
    | MenhirCell0_FAMILY_OR of 's * (
# 86 "src/parser/tokens.mly"
       (string)
# 1163 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_PLUS = 
    | MenhirCell0_FAMILY_PLUS of 's * (
# 73 "src/parser/tokens.mly"
       (string)
# 1170 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_SHARP = 
    | MenhirCell0_FAMILY_SHARP of 's * (
# 83 "src/parser/tokens.mly"
       (string)
# 1177 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TICK = 
    | MenhirCell0_FAMILY_TICK of 's * (
# 82 "src/parser/tokens.mly"
       (string)
# 1184 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FAMILY_TILDE = 
    | MenhirCell1_FAMILY_TILDE of 's * ('s, 'r) _menhir_state * (
# 84 "src/parser/tokens.mly"
       (string)
# 1191 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TIMES = 
    | MenhirCell0_FAMILY_TIMES of 's * (
# 74 "src/parser/tokens.mly"
       (string)
# 1198 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FIXITY = 
    | MenhirCell1_FIXITY of 's * ('s, 'r) _menhir_state * (
# 54 "src/parser/tokens.mly"
       (string)
# 1205 "src/parser/grammar.ml"
  ) * Lexing.position
  
  and 's _menhir_cell0_FULLSTOP = 
    | MenhirCell0_FULLSTOP of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_INDEX = 
    | MenhirCell1_INDEX of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IO_COLON = 
    | MenhirCell1_IO_COLON of 's * ('s, 'r) _menhir_state * (
# 21 "src/parser/tokens.mly"
       (char)
# 1218 "src/parser/grammar.ml"
  )
  
  and 's _menhir_cell0_IS = 
    | MenhirCell0_IS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_KIND = 
    | MenhirCell1_KIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LCURLY = 
    | MenhirCell1_LCURLY of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_LCURLY = 
    | MenhirCell0_LCURLY of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LOCAL = 
    | MenhirCell1_LOCAL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOCALKIND = 
    | MenhirCell1_LOCALKIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LPAREN = 
    | MenhirCell1_LPAREN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAREN = 
    | MenhirCell0_LPAREN of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MACRO = 
    | MenhirCell1_MACRO of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_MINUS = 
    | MenhirCell0_MINUS of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSi = 
    | MenhirCell0_MINUSi of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSr = 
    | MenhirCell0_MINUSr of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSs = 
    | MenhirCell0_MINUSs of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MOD = 
    | MenhirCell0_MOD of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODE = 
    | MenhirCell1_MODE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODULE = 
    | MenhirCell1_MODULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_NAMESPACE = 
    | MenhirCell1_NAMESPACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_OR = 
    | MenhirCell0_OR of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PIPE = 
    | MenhirCell1_PIPE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRED = 
    | MenhirCell1_PRED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_QDASH = 
    | MenhirCell0_QDASH of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_RPAREN = 
    | MenhirCell0_RPAREN of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RULE = 
    | MenhirCell1_RULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SHORTEN = 
    | MenhirCell1_SHORTEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SIG = 
    | MenhirCell1_SIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SLASH = 
    | MenhirCell0_SLASH of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPEABBREV = 
    | MenhirCell1_TYPEABBREV of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_USEONLY = 
    | MenhirCell1_USEONLY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_VDASH = 
    | MenhirCell0_VDASH of 's * Lexing.position * Lexing.position
  
  and _menhir_box_program = 
    | MenhirBox_program of (Ast.Program.t) [@@unboxed]
  
  and _menhir_box_prefix_SYMB = 
    | MenhirBox_prefix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_postfix_SYMB = 
    | MenhirBox_postfix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_infix_SYMB = 
    | MenhirBox_infix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_goal = 
    | MenhirBox_goal of (Ast.Goal.t) [@@unboxed]
  
  let _menhir_action_005 =
    fun c ->
      (
# 230 "src/parser/grammar.mly"
               ( c, [] )
# 1334 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_006 =
    fun args hd ->
      (
# 231 "src/parser/grammar.mly"
                                                                ( hd, args  )
# 1342 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_007 =
    fun () ->
      (
# 148 "src/parser/grammar.mly"
             ( ".elpi" )
# 1350 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_008 =
    fun () ->
      (
# 149 "src/parser/grammar.mly"
         ( ".mod" )
# 1358 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_009 =
    fun () ->
      (
# 150 "src/parser/grammar.mly"
            ( ".sig" )
# 1366 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_010 =
    fun () ->
      (
# 151 "src/parser/grammar.mly"
          ( ".sig" )
# 1374 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_011 =
    fun s ->
      (
# 298 "src/parser/grammar.mly"
                 ( If s )
# 1382 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_012 =
    fun s ->
      (
# 299 "src/parser/grammar.mly"
                    ( Name s )
# 1390 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_013 =
    fun s ->
      (
# 300 "src/parser/grammar.mly"
                    ( After s )
# 1398 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_014 =
    fun s ->
      (
# 301 "src/parser/grammar.mly"
                     ( Before s )
# 1406 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_015 =
    fun s ->
      (
# 302 "src/parser/grammar.mly"
                      ( Replace s )
# 1414 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_016 =
    fun () ->
      (
# 303 "src/parser/grammar.mly"
           ( External )
# 1422 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_017 =
    fun l o ->
      (
# 304 "src/parser/grammar.mly"
                                                                          ( Index (l,o) )
# 1430 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_018 =
    fun () ->
      (
# 293 "src/parser/grammar.mly"
  ( [] )
# 1438 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_019 =
    fun () ->
      (
# 294 "src/parser/grammar.mly"
           ( [ External ] )
# 1446 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_020 =
    fun l ->
      (
# 295 "src/parser/grammar.mly"
                                                       ( l )
# 1454 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_021 =
    fun c ->
      (
# 191 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin c) )
# 1462 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_022 =
    fun c ->
      (
# 192 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 1470 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_023 =
    fun t ->
      (
# 193 "src/parser/grammar.mly"
                                ( t )
# 1478 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_024 =
    fun _endpos_bind_ _startpos_bind_ b bind ->
      let _loc_bind_ = (_startpos_bind_, _endpos_bind_) in
      (
# 349 "src/parser/grammar.mly"
                        ( (loc _loc_bind_, b) )
# 1487 "src/parser/grammar.ml"
       : (Ast.Loc.t * Ast.Term.t))
  
  let _menhir_action_025 =
    fun b t ->
      (
# 346 "src/parser/grammar.mly"
                                ( mkLam (Func.show t) (snd b) )
# 1495 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_026 =
    fun b t ->
      (
# 352 "src/parser/grammar.mly"
                               ( mkLam (Func.show t) b )
# 1503 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_027 =
    fun _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove ->
      let _endpos = _endpos_new_goal_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 162 "src/parser/grammar.mly"
                                    (
    { Chr.to_match; to_remove = Util.option_default [] to_remove; guard; new_goal; attributes; loc=(loc _sloc) }
  )
# 1519 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Chr.t))
  
  let _menhir_action_028 =
    fun _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body ->
      let _endpos = _endpos_body_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_body_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 279 "src/parser/grammar.mly"
                                                  (
    { Clause.loc = loc _sloc;
      attributes;
      body;
    }
  )
# 1538 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_029 =
    fun _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r ->
      let _endpos = _endpos_r_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_l_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 285 "src/parser/grammar.mly"
                                                               ( 
    { Clause.loc = loc _sloc;
      attributes;
      body = App(Const Func.rimplf,[l;r])
    }
)
# 1557 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_030 =
    fun t ->
      (
# 380 "src/parser/grammar.mly"
               ( Const t )
# 1565 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_031 =
    fun t ->
      (
# 381 "src/parser/grammar.mly"
                           ( t )
# 1573 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_032 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 384 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 1586 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_033 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1595 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1600 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1609 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_034 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1618 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1623 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1632 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_035 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1641 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1646 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1655 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_036 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1664 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1669 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1678 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_037 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1687 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1692 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1701 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_038 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1710 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1715 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1724 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_039 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1733 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1738 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1747 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_040 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 453 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1756 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1761 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1770 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_041 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 454 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 1779 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1784 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1793 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_042 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 455 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1802 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1807 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1816 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_043 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 456 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1825 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1830 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1839 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_044 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 457 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1848 "src/parser/grammar.ml"
         in
        
# 442 "src/parser/grammar.mly"
                       ( x )
# 1853 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1862 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_045 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.consf )
# 1872 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 1877 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 1883 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1892 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_046 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.eqf )
# 1902 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 1907 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 1913 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1922 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_047 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 1932 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 1937 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 1943 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1952 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_048 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 1962 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 1967 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 1973 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1982 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_049 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 1992 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 1997 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2003 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2012 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_050 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 2022 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2027 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2033 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2042 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_051 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 2052 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2057 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2063 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2072 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_052 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.orf )
# 2082 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2087 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2093 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2102 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_053 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.isf )
# 2112 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2117 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2123 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2132 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_054 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 2142 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2147 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2153 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2162 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_055 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 470 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 2172 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2177 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2183 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2192 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_056 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 471 "src/parser/grammar.mly"
         ( Func.arrowf )
# 2202 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2207 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2213 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2222 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_057 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 472 "src/parser/grammar.mly"
         ( Func.implf )
# 2232 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2237 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2243 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2252 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_058 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 473 "src/parser/grammar.mly"
         ( Func.sequentf )
# 2262 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2267 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2273 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2282 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_059 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 474 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 2292 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2297 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2303 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2312 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_060 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 475 "src/parser/grammar.mly"
         ( Func.andf )
# 2322 "src/parser/grammar.ml"
           in
          
# 478 "src/parser/grammar.mly"
                                          ( x )
# 2327 "src/parser/grammar.ml"
          
        in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2333 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2342 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_061 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 479 "src/parser/grammar.mly"
         ( Func.andf )
# 2351 "src/parser/grammar.ml"
         in
        
# 443 "src/parser/grammar.mly"
                                   ( x )
# 2356 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 389 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2365 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_062 =
    fun r s ->
      let s =
        let x = 
# 490 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2374 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                        ( x )
# 2379 "src/parser/grammar.ml"
        
      in
      (
# 390 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 2385 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_063 =
    fun l s ->
      let s =
        let x = 
# 493 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2394 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                         ( x )
# 2399 "src/parser/grammar.ml"
        
      in
      (
# 391 "src/parser/grammar.mly"
                                   ( App(Const s,[l]) )
# 2405 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_064 =
    fun t ->
      (
# 376 "src/parser/grammar.mly"
                          ( t )
# 2413 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_065 =
    fun t ->
      (
# 377 "src/parser/grammar.mly"
                            ( t )
# 2421 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_066 =
    fun x ->
      (
# 321 "src/parser/grammar.mly"
              ( mkC (cint.Util.CData.cin x))
# 2429 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_067 =
    fun x ->
      (
# 322 "src/parser/grammar.mly"
            ( mkC (cfloat.Util.CData.cin x))
# 2437 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_068 =
    fun x ->
      (
# 323 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin x))
# 2445 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_069 =
    fun _endpos_x_ _startpos_x_ x ->
      let _endpos = _endpos_x_ in
      let _startpos = _startpos_x_ in
      let _loc = (_startpos, _endpos) in
      (
# 324 "src/parser/grammar.mly"
             ( mkQuoted (loc _loc) x )
# 2456 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_070 =
    fun c t ->
      (
# 325 "src/parser/grammar.mly"
                                         ( App(mkCon "as",[t;c]) )
# 2464 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_071 =
    fun l ->
      (
# 326 "src/parser/grammar.mly"
                           ( mkSeq l )
# 2472 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_072 =
    fun l ->
      (
# 327 "src/parser/grammar.mly"
                                  (  mkSeq l )
# 2480 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_073 =
    fun t ->
      (
# 328 "src/parser/grammar.mly"
                           ( App (Const Func.spillf,[t]) )
# 2488 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_074 =
    fun t ->
      (
# 329 "src/parser/grammar.mly"
                ( t )
# 2496 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_075 =
    fun c ->
      (
# 394 "src/parser/grammar.mly"
               (
    if c = "nil" then Func.nilf
    else if c = "cons" then Func.consf
    else Func.from_string c )
# 2507 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_076 =
    fun () ->
      (
# 398 "src/parser/grammar.mly"
     ( Func.from_string "if" )
# 2515 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_077 =
    fun () ->
      (
# 399 "src/parser/grammar.mly"
       ( Func.from_string "name" )
# 2523 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_078 =
    fun () ->
      (
# 400 "src/parser/grammar.mly"
         ( Func.from_string "before" )
# 2531 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_079 =
    fun () ->
      (
# 401 "src/parser/grammar.mly"
        ( Func.from_string "after" )
# 2539 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_080 =
    fun () ->
      (
# 402 "src/parser/grammar.mly"
          ( Func.from_string "replace" )
# 2547 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_081 =
    fun () ->
      (
# 403 "src/parser/grammar.mly"
        ( Func.from_string "index" )
# 2555 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_082 =
    fun c ->
      (
# 404 "src/parser/grammar.mly"
         ( Func.from_string @@ String.make 1 c )
# 2563 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_083 =
    fun () ->
      (
# 405 "src/parser/grammar.mly"
      ( Func.cutf )
# 2571 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_084 =
    fun () ->
      (
# 406 "src/parser/grammar.mly"
     ( Func.pif )
# 2579 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_085 =
    fun () ->
      (
# 407 "src/parser/grammar.mly"
        ( Func.sigmaf )
# 2587 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_086 =
    fun () ->
      (
# 408 "src/parser/grammar.mly"
          ( Func.dummyname )
# 2595 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_087 =
    fun s ->
      (
# 409 "src/parser/grammar.mly"
                                  ( s )
# 2603 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_088 =
    fun () ->
      (
# 410 "src/parser/grammar.mly"
                      ( Func.from_string "as" )
# 2611 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_089 =
    fun () ->
      (
# 411 "src/parser/grammar.mly"
      ( Func.nilf )
# 2619 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_090 =
    fun c ->
      (
# 122 "src/parser/grammar.mly"
                       ( Program.Clause c )
# 2627 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_091 =
    fun r ->
      (
# 123 "src/parser/grammar.mly"
                         ( Program.Chr r )
# 2635 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_092 =
    fun p ->
      (
# 124 "src/parser/grammar.mly"
                     ( Program.Pred (snd p, fst p) )
# 2643 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_093 =
    fun t ->
      (
# 125 "src/parser/grammar.mly"
                      ( Program.Type t )
# 2651 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_094 =
    fun t ->
      (
# 126 "src/parser/grammar.mly"
                     ( Program.Type t )
# 2659 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_095 =
    fun m ->
      (
# 127 "src/parser/grammar.mly"
                     ( Program.Mode [m] )
# 2667 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_096 =
    fun m ->
      (
# 128 "src/parser/grammar.mly"
                      ( Program.Macro m )
# 2675 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_097 =
    fun _endpos__5_ _startpos__1_ cl hyps ->
      let _endpos = _endpos__5_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 129 "src/parser/grammar.mly"
                                                                        ( Program.Constraint(loc _sloc, hyps, cl) )
# 2686 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_098 =
    fun _endpos__3_ _startpos__1_ cl ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 130 "src/parser/grammar.mly"
                                          ( Program.Constraint(loc _sloc, [], cl) )
# 2697 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_099 =
    fun _endpos__3_ _startpos__1_ c ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 131 "src/parser/grammar.mly"
                                  ( Program.Namespace(loc _sloc, c ))
# 2708 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_100 =
    fun _endpos__3_ _startpos__1_ s ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 132 "src/parser/grammar.mly"
                                 ( Program.Shorten(loc _sloc, s) )
# 2719 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_101 =
    fun a ->
      (
# 133 "src/parser/grammar.mly"
                           ( Program.TypeAbbreviation a )
# 2727 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_102 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 134 "src/parser/grammar.mly"
         ( Program.Begin (loc _sloc) )
# 2738 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_103 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 135 "src/parser/grammar.mly"
         ( Program.End (loc _sloc) )
# 2749 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_104 =
    fun _endpos__3_ _startpos_ext_ ext l ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos_ext_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 136 "src/parser/grammar.mly"
                                                                         (
    Program.Accumulated(loc _sloc,List.(concat (map (fun x ->
      let cwd = Filename.dirname (loc _sloc).source_name in
      C.parse_file ~cwd (x ^ ext)) l)))
  )
# 2764 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_105 =
    fun l ->
      (
# 141 "src/parser/grammar.mly"
                                                                                 (
    Program.Local l
  )
# 2774 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_106 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 144 "src/parser/grammar.mly"
                    ( Program.Ignored (loc _sloc) )
# 2785 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_107 =
    fun _endpos__2_ _startpos_f_ f ->
      let _endpos = _endpos__2_ in
      let _startpos = _startpos_f_ in
      let _loc = (_startpos, _endpos) in
      (
# 145 "src/parser/grammar.mly"
                       ( error_mixfix (loc _loc) )
# 2796 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_108 =
    fun c ->
      (
# 154 "src/parser/grammar.mly"
               ( Func.show c )
# 2804 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_109 =
    fun s ->
      (
# 155 "src/parser/grammar.mly"
             ( s )
# 2812 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_110 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 246 "src/parser/grammar.mly"
                                        ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2821 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_111 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 247 "src/parser/grammar.mly"
                                           ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2830 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_112 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 275 "src/parser/grammar.mly"
                ( ( loc _sloc , g ) )
# 2841 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_113 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 276 "src/parser/grammar.mly"
                     ( ( loc _sloc , g ) )
# 2852 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_114 =
    fun t ->
      (
# 332 "src/parser/grammar.mly"
               ( Const t )
# 2860 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_115 =
    fun t ->
      (
# 333 "src/parser/grammar.mly"
                           ( t )
# 2868 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_116 =
    fun io ->
      (
# 209 "src/parser/grammar.mly"
          ( mode_of_IO io )
# 2876 "src/parser/grammar.ml"
       : (bool))
  
  let _menhir_action_117 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2887 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_118 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2898 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_119 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2909 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_120 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2920 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_121 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2931 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_122 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2942 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_123 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2953 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_124 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 243 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2964 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_125 =
    fun () ->
      (
# 307 "src/parser/grammar.mly"
          ( 0 )
# 2972 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_126 =
    fun i ->
      (
# 308 "src/parser/grammar.mly"
              ( i )
# 2980 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_127 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2989 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 2994 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3000 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_128 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3009 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3014 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3020 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_129 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3029 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3034 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3040 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_130 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3049 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3054 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3060 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_131 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3069 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3074 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3080 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_132 =
    fun s ->
      let x =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3089 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3094 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3100 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_133 =
    fun s ->
      let x =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3109 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3114 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3120 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_134 =
    fun s ->
      let x =
        let x = 
# 453 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3129 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3134 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3140 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_135 =
    fun s ->
      let x =
        let x = 
# 454 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 3149 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3154 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3160 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_136 =
    fun s ->
      let x =
        let x = 
# 455 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3169 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3174 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3180 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_137 =
    fun s ->
      let x =
        let x = 
# 456 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3189 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3194 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3200 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_138 =
    fun s ->
      let x =
        let x = 
# 457 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3209 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3214 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3220 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_139 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.consf )
# 3231 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3236 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3242 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3248 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3254 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_140 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.eqf )
# 3265 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3270 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3276 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3282 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3288 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_141 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 3299 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3304 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3310 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3316 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3322 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_142 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 3333 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3338 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3344 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3350 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3356 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_143 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 3367 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3372 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3378 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3384 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3390 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_144 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 3401 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3406 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3412 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3418 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3424 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_145 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 3435 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3440 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3446 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3452 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3458 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_146 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.orf )
# 3469 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3474 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3480 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3486 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3492 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_147 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.isf )
# 3503 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3508 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3514 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3520 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3526 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_148 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 3537 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3542 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3548 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3554 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3560 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_149 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 3571 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3576 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3582 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3588 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3594 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_150 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 471 "src/parser/grammar.mly"
         ( Func.arrowf )
# 3605 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3610 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3616 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3622 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3628 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_151 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 472 "src/parser/grammar.mly"
         ( Func.implf )
# 3639 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3644 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3650 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3656 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3662 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_152 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 473 "src/parser/grammar.mly"
         ( Func.sequentf )
# 3673 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3678 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3684 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3690 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3696 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_153 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 474 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 3707 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3712 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3718 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3724 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3730 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_154 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 475 "src/parser/grammar.mly"
         ( Func.andf )
# 3741 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 3746 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3752 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3758 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3764 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_155 =
    fun () ->
      let x =
        let x =
          let x = 
# 479 "src/parser/grammar.mly"
         ( Func.andf )
# 3774 "src/parser/grammar.ml"
           in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 3779 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3785 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3791 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_156 =
    fun () ->
      let x =
        let x = 
# 487 "src/parser/grammar.mly"
         ( Func.rimplf )
# 3800 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 3805 "src/parser/grammar.ml"
        
      in
      (
# 419 "src/parser/grammar.mly"
            ( x )
# 3811 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_157 =
    fun _endpos_k_ _startpos__1_ k names ->
      let _endpos = _endpos_k_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 179 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes=[]; name =  n; ty = k })
  )
# 3825 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_158 =
    fun () ->
      (
# 201 "src/parser/grammar.mly"
       ( mkCon "type" )
# 3833 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_159 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 202 "src/parser/grammar.mly"
                                  ( mkApp (loc _loc_hd_) [mkCon "->"; mkCon "type"; t] )
# 3842 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_160 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 3850 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_161 =
    fun x xs ->
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 3858 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_162 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 3866 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_163 =
    fun x xs ->
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 3874 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_164 =
    fun () ->
      (
# 336 "src/parser/grammar.mly"
           ( [mkNil] )
# 3882 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_165 =
    fun x ->
      (
# 337 "src/parser/grammar.mly"
                            ( [x;mkNil] )
# 3890 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_166 =
    fun x xs ->
      (
# 338 "src/parser/grammar.mly"
                                         ( x :: xs )
# 3898 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_167 =
    fun x ->
      (
# 341 "src/parser/grammar.mly"
                                  ( [x] )
# 3906 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_168 =
    fun x xs ->
      (
# 342 "src/parser/grammar.mly"
                                                    ( [x;xs] )
# 3914 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_169 =
    fun x xs ->
      (
# 343 "src/parser/grammar.mly"
                                              ( x :: xs )
# 3922 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_170 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 3930 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_171 =
    fun x ->
      (
# 148 "<standard.mly>"
    ( x )
# 3938 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_172 =
    fun _endpos_b_ _startpos__1_ b m ->
      let _endpos = _endpos_b_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 212 "src/parser/grammar.mly"
                                   (
  let name, body = desugar_macro (loc _sloc) m b in
  { Macro.loc = loc _sloc; name; body }
)
# 3952 "src/parser/grammar.ml"
       : ((Ast.Func.t, Ast.Term.t) Ast.Macro.t))
  
  let _menhir_action_173 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3961 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3966 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3972 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_174 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3981 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 3986 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3992 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_175 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4001 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4006 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4012 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_176 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4021 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4026 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4032 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_177 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4041 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4046 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4052 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_178 =
    fun s ->
      let x =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4061 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4066 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4072 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_179 =
    fun s ->
      let x =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4081 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4086 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4092 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_180 =
    fun s ->
      let x =
        let x = 
# 453 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4101 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4106 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4112 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_181 =
    fun s ->
      let x =
        let x = 
# 454 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 4121 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4126 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4132 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_182 =
    fun s ->
      let x =
        let x = 
# 455 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4141 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4146 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4152 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_183 =
    fun s ->
      let x =
        let x = 
# 456 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4161 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4166 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4172 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_184 =
    fun s ->
      let x =
        let x = 
# 457 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4181 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4186 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4192 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_185 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.consf )
# 4203 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4208 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4214 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4220 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4226 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_186 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.eqf )
# 4237 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4242 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4248 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4254 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4260 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_187 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 4271 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4276 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4282 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4288 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4294 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_188 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 4305 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4310 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4316 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4322 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4328 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_189 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 4339 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4344 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4350 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4356 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4362 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_190 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 4373 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4378 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4384 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4390 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4396 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_191 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 4407 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4412 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4418 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4424 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4430 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_192 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.orf )
# 4441 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4446 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4452 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4458 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4464 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_193 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.isf )
# 4475 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4480 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4486 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4492 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4498 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_194 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 4509 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4514 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4520 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4526 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4532 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_195 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 4543 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4548 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4554 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4560 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4566 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_196 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 471 "src/parser/grammar.mly"
         ( Func.arrowf )
# 4577 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4582 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4588 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4594 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4600 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_197 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 472 "src/parser/grammar.mly"
         ( Func.implf )
# 4611 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4616 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4622 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4628 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4634 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_198 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 473 "src/parser/grammar.mly"
         ( Func.sequentf )
# 4645 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4650 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4656 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4662 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4668 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_199 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 474 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 4679 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4684 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4690 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4696 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4702 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_200 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 475 "src/parser/grammar.mly"
         ( Func.andf )
# 4713 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 4718 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4724 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4730 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4736 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_201 =
    fun () ->
      let x =
        let x =
          let x = 
# 479 "src/parser/grammar.mly"
         ( Func.andf )
# 4746 "src/parser/grammar.ml"
           in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 4751 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4757 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4763 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_202 =
    fun () ->
      let x =
        let x = 
# 487 "src/parser/grammar.mly"
         ( Func.rimplf )
# 4772 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 4777 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 4783 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_203 =
    fun s ->
      let x =
        let x = 
# 490 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4792 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                        ( x )
# 4797 "src/parser/grammar.ml"
        
      in
      (
# 415 "src/parser/grammar.mly"
             ( x )
# 4803 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_204 =
    fun s ->
      let x =
        let x = 
# 493 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4812 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                         ( x )
# 4817 "src/parser/grammar.ml"
        
      in
      (
# 416 "src/parser/grammar.mly"
              ( x )
# 4823 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_205 =
    fun _endpos__5_ _startpos__1_ c l ->
      let _endpos = _endpos__5_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 205 "src/parser/grammar.mly"
                                                             (
    { Mode.name = c; args = l; loc = loc _sloc } 
)
# 4836 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t))
  
  let _menhir_action_206 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4844 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_207 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4852 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_208 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4860 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_209 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4868 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_210 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4876 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_211 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4884 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_212 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4892 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_213 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4900 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_214 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4908 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_215 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4916 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_216 =
    fun x ->
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 4924 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_217 =
    fun x xs ->
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 4932 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_218 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 355 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 4945 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_219 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4954 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4959 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4968 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_220 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4977 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 4982 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4991 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_221 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5000 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5005 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5014 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_222 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5023 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5028 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5037 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_223 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5046 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5051 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5060 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_224 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5069 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5074 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5083 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_225 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5092 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5097 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5106 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_226 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 453 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5115 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5120 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5129 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_227 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 454 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 5138 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5143 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5152 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_228 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 455 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5161 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5166 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5175 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_229 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 456 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5184 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5189 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5198 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_230 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 457 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5207 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                       ( x )
# 5212 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5221 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_231 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.consf )
# 5232 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5237 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5243 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5249 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5258 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_232 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.eqf )
# 5269 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5274 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5280 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5286 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5295 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_233 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 5306 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5311 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5317 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5323 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5332 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_234 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 5343 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5348 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5354 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5360 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5369 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_235 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 5380 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5385 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5391 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5397 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5406 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_236 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 5417 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5422 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5428 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5434 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5443 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_237 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 5454 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5459 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5465 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5471 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5480 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_238 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.orf )
# 5491 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5496 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5502 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5508 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5517 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_239 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.isf )
# 5528 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5533 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5539 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5545 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5554 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_240 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 5565 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5570 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5576 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5582 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5591 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_241 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 5602 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5607 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5613 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5619 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5628 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_242 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 471 "src/parser/grammar.mly"
         ( Func.arrowf )
# 5639 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5644 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5650 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5656 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5665 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_243 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 472 "src/parser/grammar.mly"
         ( Func.implf )
# 5676 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5681 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5687 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5693 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5702 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_244 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 473 "src/parser/grammar.mly"
         ( Func.sequentf )
# 5713 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5718 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5724 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5730 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5739 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_245 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 474 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 5750 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5755 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5761 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5767 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5776 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_246 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 475 "src/parser/grammar.mly"
         ( Func.andf )
# 5787 "src/parser/grammar.ml"
             in
            
# 478 "src/parser/grammar.mly"
                                          ( x )
# 5792 "src/parser/grammar.ml"
            
          in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5798 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5804 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5813 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_247 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 479 "src/parser/grammar.mly"
         ( Func.andf )
# 5823 "src/parser/grammar.ml"
           in
          
# 486 "src/parser/grammar.mly"
                                   ( x )
# 5828 "src/parser/grammar.ml"
          
        in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5834 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5843 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_248 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 487 "src/parser/grammar.mly"
         ( Func.rimplf )
# 5852 "src/parser/grammar.ml"
         in
        
# 435 "src/parser/grammar.mly"
                           ( x )
# 5857 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 360 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5866 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_249 =
    fun r s ->
      let s =
        let x = 
# 490 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5875 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                        ( x )
# 5880 "src/parser/grammar.ml"
        
      in
      (
# 361 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 5886 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_250 =
    fun l s ->
      let s =
        let x = 
# 493 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5895 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                         ( x )
# 5900 "src/parser/grammar.ml"
        
      in
      (
# 362 "src/parser/grammar.mly"
                         ( App(Const s,[l]) )
# 5906 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_251 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 365 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 5919 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_252 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5928 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 5933 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5942 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_253 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5951 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 5956 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5965 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_254 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5974 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 5979 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5988 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_255 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5997 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6002 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6011 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_256 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6020 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6025 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6034 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_257 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6043 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6048 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6057 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_258 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6066 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6071 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6080 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_259 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 453 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6089 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6094 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6103 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_260 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 454 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 6112 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6117 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6126 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_261 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 455 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6135 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6140 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6149 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_262 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 456 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6158 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6163 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6172 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_263 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 457 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6181 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                       ( x )
# 6186 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6195 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_264 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.consf )
# 6205 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6210 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6216 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6225 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_265 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.eqf )
# 6235 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6240 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6246 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6255 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_266 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 6265 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6270 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6276 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6285 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_267 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 6295 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6300 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6306 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6315 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_268 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 6325 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6330 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6336 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6345 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_269 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 6355 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6360 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6366 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6375 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_270 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 6385 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6390 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6396 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6405 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_271 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.orf )
# 6415 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6420 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6426 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6435 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_272 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.isf )
# 6445 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6450 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6456 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6465 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_273 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 6475 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6480 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6486 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6495 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_274 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 470 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 6505 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6510 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6516 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6525 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_275 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 471 "src/parser/grammar.mly"
         ( Func.arrowf )
# 6535 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6540 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6546 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6555 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_276 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 472 "src/parser/grammar.mly"
         ( Func.implf )
# 6565 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6570 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6576 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6585 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_277 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 473 "src/parser/grammar.mly"
         ( Func.sequentf )
# 6595 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6600 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6606 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6615 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_278 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 474 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 6625 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6630 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6636 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6645 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_279 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 475 "src/parser/grammar.mly"
         ( Func.andf )
# 6655 "src/parser/grammar.ml"
           in
          
# 482 "src/parser/grammar.mly"
                                          ( x )
# 6660 "src/parser/grammar.ml"
          
        in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6666 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6675 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_280 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 483 "src/parser/grammar.mly"
         ( Func.rimplf )
# 6684 "src/parser/grammar.ml"
         in
        
# 439 "src/parser/grammar.mly"
                                  ( x )
# 6689 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 370 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6698 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_281 =
    fun r s ->
      let s =
        let x = 
# 490 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6707 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                        ( x )
# 6712 "src/parser/grammar.ml"
        
      in
      (
# 371 "src/parser/grammar.mly"
                              ( App(Const s,[r]) )
# 6718 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_282 =
    fun l s ->
      let s =
        let x = 
# 493 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6727 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                         ( x )
# 6732 "src/parser/grammar.ml"
        
      in
      (
# 372 "src/parser/grammar.mly"
                                ( App(Const s,[l]) )
# 6738 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_283 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6746 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_284 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6754 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_285 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6762 "src/parser/grammar.ml"
       : (string option))
  
  let _menhir_action_286 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6770 "src/parser/grammar.ml"
       : (string option))
  
  let _menhir_action_287 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6778 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_288 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6786 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_289 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6794 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_290 =
    fun x ->
      let x = 
# 188 "<standard.mly>"
    ( x )
# 6802 "src/parser/grammar.ml"
       in
      (
# 114 "<standard.mly>"
    ( Some x )
# 6807 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_291 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6815 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_292 =
    fun x ->
      let x = 
# 188 "<standard.mly>"
    ( x )
# 6823 "src/parser/grammar.ml"
       in
      (
# 114 "<standard.mly>"
    ( Some x )
# 6828 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_293 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6836 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_294 =
    fun x ->
      let x = 
# 188 "<standard.mly>"
    ( x )
# 6844 "src/parser/grammar.ml"
       in
      (
# 114 "<standard.mly>"
    ( Some x )
# 6849 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_295 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6857 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_296 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 6865 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_297 =
    fun s ->
      let x =
        let x = 
# 493 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6874 "src/parser/grammar.ml"
         in
        
# 431 "src/parser/grammar.mly"
                         ( x )
# 6879 "src/parser/grammar.ml"
        
      in
      (
# 425 "src/parser/grammar.mly"
              ( x )
# 6885 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_298 =
    fun _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs ->
      let args = 
# 241 "<standard.mly>"
    ( xs )
# 6893 "src/parser/grammar.ml"
       in
      let _endpos_args_ = _endpos_xs_ in
      let _endpos = _endpos_args_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 168 "src/parser/grammar.mly"
                                                              (
   let name = c in
   { Mode.loc=loc _sloc; name; args = List.map fst args },
   { Type.loc=loc _sloc; attributes; name;
     ty = List.fold_right (fun (_,t) ty ->
       mkApp (loc _loc_c_) [mkCon "->";t;ty]) args (mkCon "prop") }
 )
# 6912 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t * Ast.raw_attribute list Ast.Type.t))
  
  let _menhir_action_299 =
    fun io ty ->
      (
# 176 "src/parser/grammar.mly"
                                ( (mode_of_IO io,ty) )
# 6920 "src/parser/grammar.ml"
       : (bool * Ast.Term.t))
  
  let _menhir_action_300 =
    fun s ->
      let x =
        let x = 
# 490 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6929 "src/parser/grammar.ml"
         in
        
# 428 "src/parser/grammar.mly"
                        ( x )
# 6934 "src/parser/grammar.ml"
        
      in
      (
# 422 "src/parser/grammar.mly"
             ( x )
# 6940 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_301 =
    fun () ->
      (
# 118 "src/parser/grammar.mly"
      ( [] )
# 6948 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_302 =
    fun d p ->
      (
# 119 "src/parser/grammar.mly"
                        ( d :: p )
# 6956 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_303 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 6964 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_304 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 6972 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_305 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 6980 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_306 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 6988 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_307 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 6996 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_308 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 7004 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_309 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 7012 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_310 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 7020 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_311 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 7028 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_312 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 7036 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_313 =
    fun t ->
      (
# 265 "src/parser/grammar.mly"
                  (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = underscore (); context; conclusion }
  )
# 7047 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_314 =
    fun c t ->
      (
# 269 "src/parser/grammar.mly"
                                                   (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = c; context; conclusion }
  )
# 7058 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_315 =
    fun l ->
      (
# 250 "src/parser/grammar.mly"
           (
     List.map Func.(fun (x,y) -> from_string x, from_string y) l
  )
# 7068 "src/parser/grammar.ml"
       : ((Ast.Func.t * Ast.Func.t) list))
  
  let _menhir_action_316 =
    fun name ->
      (
# 259 "src/parser/grammar.mly"
                  ( [Func.show name, Func.show name] )
# 7076 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_317 =
    fun l prefix ->
      (
# 260 "src/parser/grammar.mly"
                                                                                         (
    List.map (fun (p,x) -> Func.show prefix ^ "." ^ p, x) (List.flatten l)
)
# 7086 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_318 =
    fun t ->
      (
# 311 "src/parser/grammar.mly"
                ( t )
# 7094 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_319 =
    fun t ->
      (
# 312 "src/parser/grammar.mly"
                  ( t )
# 7102 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_320 =
    fun t ->
      (
# 313 "src/parser/grammar.mly"
                  ( t )
# 7110 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_321 =
    fun t ->
      (
# 316 "src/parser/grammar.mly"
                       ( t )
# 7118 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_322 =
    fun t ->
      (
# 317 "src/parser/grammar.mly"
                         ( t )
# 7126 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_323 =
    fun t ->
      (
# 318 "src/parser/grammar.mly"
                  ( t )
# 7134 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_324 =
    fun c l ->
      (
# 255 "src/parser/grammar.mly"
                                                                                    (
    List.map (fun (p,x) -> Func.show c ^ "." ^ p, x) (List.flatten l)
)
# 7144 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_325 =
    fun _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 185 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes; name = n; ty = t })
  )
# 7161 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_326 =
    fun c ->
      (
# 195 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 7169 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_327 =
    fun _endpos_hd_ _startpos_hd_ args hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 196 "src/parser/grammar.mly"
                                                  ( mkAppF (loc _loc_hd_) hd args )
# 7178 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_328 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 197 "src/parser/grammar.mly"
                                       ( mkApp (loc _loc_hd_) [mkCon "->"; hd; t] )
# 7187 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_329 =
    fun t ->
      (
# 198 "src/parser/grammar.mly"
                                ( t )
# 7195 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_330 =
    fun _endpos_t_ _startpos__1_ a t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 218 "src/parser/grammar.mly"
                                            (
    let name, args = a in
    let args = List.map Func.show args in
    let nparams = List.length args in
    let value = List.fold_right mkLam args t in
    { TypeAbbreviation.name = name;
      nparams = nparams;
      value = value;
      loc = loc _sloc }
  )
# 7215 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.TypeAbbreviation.t))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Elpi_lexer_config.Tokens.ACCUMULATE ->
          "ACCUMULATE"
      | Elpi_lexer_config.Tokens.ACCUM_SIG ->
          "ACCUM_SIG"
      | Elpi_lexer_config.Tokens.AFTER ->
          "AFTER"
      | Elpi_lexer_config.Tokens.ARROW ->
          "ARROW"
      | Elpi_lexer_config.Tokens.AS ->
          "AS"
      | Elpi_lexer_config.Tokens.BEFORE ->
          "BEFORE"
      | Elpi_lexer_config.Tokens.BIND ->
          "BIND"
      | Elpi_lexer_config.Tokens.CLOSED ->
          "CLOSED"
      | Elpi_lexer_config.Tokens.COLON ->
          "COLON"
      | Elpi_lexer_config.Tokens.CONJ ->
          "CONJ"
      | Elpi_lexer_config.Tokens.CONJ2 ->
          "CONJ2"
      | Elpi_lexer_config.Tokens.CONS ->
          "CONS"
      | Elpi_lexer_config.Tokens.CONSTANT _ ->
          "CONSTANT"
      | Elpi_lexer_config.Tokens.CONSTRAINT ->
          "CONSTRAINT"
      | Elpi_lexer_config.Tokens.CUT ->
          "CUT"
      | Elpi_lexer_config.Tokens.DARROW ->
          "DARROW"
      | Elpi_lexer_config.Tokens.DIV ->
          "DIV"
      | Elpi_lexer_config.Tokens.EOF ->
          "EOF"
      | Elpi_lexer_config.Tokens.EQ ->
          "EQ"
      | Elpi_lexer_config.Tokens.EQ2 ->
          "EQ2"
      | Elpi_lexer_config.Tokens.EXPORTDEF ->
          "EXPORTDEF"
      | Elpi_lexer_config.Tokens.EXTERNAL ->
          "EXTERNAL"
      | Elpi_lexer_config.Tokens.FAMILY_AND _ ->
          "FAMILY_AND"
      | Elpi_lexer_config.Tokens.FAMILY_BTICK _ ->
          "FAMILY_BTICK"
      | Elpi_lexer_config.Tokens.FAMILY_EQ _ ->
          "FAMILY_EQ"
      | Elpi_lexer_config.Tokens.FAMILY_EXP _ ->
          "FAMILY_EXP"
      | Elpi_lexer_config.Tokens.FAMILY_GT _ ->
          "FAMILY_GT"
      | Elpi_lexer_config.Tokens.FAMILY_LT _ ->
          "FAMILY_LT"
      | Elpi_lexer_config.Tokens.FAMILY_MINUS _ ->
          "FAMILY_MINUS"
      | Elpi_lexer_config.Tokens.FAMILY_OR _ ->
          "FAMILY_OR"
      | Elpi_lexer_config.Tokens.FAMILY_PLUS _ ->
          "FAMILY_PLUS"
      | Elpi_lexer_config.Tokens.FAMILY_QMARK _ ->
          "FAMILY_QMARK"
      | Elpi_lexer_config.Tokens.FAMILY_SHARP _ ->
          "FAMILY_SHARP"
      | Elpi_lexer_config.Tokens.FAMILY_TICK _ ->
          "FAMILY_TICK"
      | Elpi_lexer_config.Tokens.FAMILY_TILDE _ ->
          "FAMILY_TILDE"
      | Elpi_lexer_config.Tokens.FAMILY_TIMES _ ->
          "FAMILY_TIMES"
      | Elpi_lexer_config.Tokens.FIXITY _ ->
          "FIXITY"
      | Elpi_lexer_config.Tokens.FLOAT _ ->
          "FLOAT"
      | Elpi_lexer_config.Tokens.FRESHUV ->
          "FRESHUV"
      | Elpi_lexer_config.Tokens.FULLSTOP ->
          "FULLSTOP"
      | Elpi_lexer_config.Tokens.IF ->
          "IF"
      | Elpi_lexer_config.Tokens.IFF ->
          "IFF"
      | Elpi_lexer_config.Tokens.IMPORT ->
          "IMPORT"
      | Elpi_lexer_config.Tokens.INDEX ->
          "INDEX"
      | Elpi_lexer_config.Tokens.INTEGER _ ->
          "INTEGER"
      | Elpi_lexer_config.Tokens.IO _ ->
          "IO"
      | Elpi_lexer_config.Tokens.IO_COLON _ ->
          "IO_COLON"
      | Elpi_lexer_config.Tokens.IS ->
          "IS"
      | Elpi_lexer_config.Tokens.KIND ->
          "KIND"
      | Elpi_lexer_config.Tokens.LBRACKET ->
          "LBRACKET"
      | Elpi_lexer_config.Tokens.LCURLY ->
          "LCURLY"
      | Elpi_lexer_config.Tokens.LOCAL ->
          "LOCAL"
      | Elpi_lexer_config.Tokens.LOCALKIND ->
          "LOCALKIND"
      | Elpi_lexer_config.Tokens.LPAREN ->
          "LPAREN"
      | Elpi_lexer_config.Tokens.MACRO ->
          "MACRO"
      | Elpi_lexer_config.Tokens.MINUS ->
          "MINUS"
      | Elpi_lexer_config.Tokens.MINUSi ->
          "MINUSi"
      | Elpi_lexer_config.Tokens.MINUSr ->
          "MINUSr"
      | Elpi_lexer_config.Tokens.MINUSs ->
          "MINUSs"
      | Elpi_lexer_config.Tokens.MOD ->
          "MOD"
      | Elpi_lexer_config.Tokens.MODE ->
          "MODE"
      | Elpi_lexer_config.Tokens.MODULE ->
          "MODULE"
      | Elpi_lexer_config.Tokens.NAME ->
          "NAME"
      | Elpi_lexer_config.Tokens.NAMESPACE ->
          "NAMESPACE"
      | Elpi_lexer_config.Tokens.NIL ->
          "NIL"
      | Elpi_lexer_config.Tokens.OR ->
          "OR"
      | Elpi_lexer_config.Tokens.PI ->
          "PI"
      | Elpi_lexer_config.Tokens.PIPE ->
          "PIPE"
      | Elpi_lexer_config.Tokens.PRED ->
          "PRED"
      | Elpi_lexer_config.Tokens.QDASH ->
          "QDASH"
      | Elpi_lexer_config.Tokens.QUOTED _ ->
          "QUOTED"
      | Elpi_lexer_config.Tokens.RBRACKET ->
          "RBRACKET"
      | Elpi_lexer_config.Tokens.RCURLY ->
          "RCURLY"
      | Elpi_lexer_config.Tokens.REPLACE ->
          "REPLACE"
      | Elpi_lexer_config.Tokens.RPAREN ->
          "RPAREN"
      | Elpi_lexer_config.Tokens.RULE ->
          "RULE"
      | Elpi_lexer_config.Tokens.SHORTEN ->
          "SHORTEN"
      | Elpi_lexer_config.Tokens.SIG ->
          "SIG"
      | Elpi_lexer_config.Tokens.SIGMA ->
          "SIGMA"
      | Elpi_lexer_config.Tokens.SLASH ->
          "SLASH"
      | Elpi_lexer_config.Tokens.STRING _ ->
          "STRING"
      | Elpi_lexer_config.Tokens.TYPE ->
          "TYPE"
      | Elpi_lexer_config.Tokens.TYPEABBREV ->
          "TYPEABBREV"
      | Elpi_lexer_config.Tokens.USEONLY ->
          "USEONLY"
      | Elpi_lexer_config.Tokens.USE_SIG ->
          "USE_SIG"
      | Elpi_lexer_config.Tokens.VDASH ->
          "VDASH"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37"]
    
    let _menhir_run_406 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        MenhirBox_program _v
    
    let rec _menhir_goto_program : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState419 ->
            _menhir_run_420 _menhir_stack _v
        | MenhirState268 ->
            _menhir_run_406 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_420 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_decl -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, d) = _menhir_stack in
        let p = _v in
        let _v = _menhir_action_302 d p in
        _menhir_goto_program _menhir_stack _v _menhir_s
    
    let _menhir_run_363 : type  ttv_stack. ttv_stack -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_s ->
        let _v = _menhir_action_301 () in
        _menhir_goto_program _menhir_stack _v _menhir_s
    
    let _menhir_goto_goal : type  ttv_stack. ttv_stack -> _ -> _menhir_box_goal =
      fun _menhir_stack _v ->
        MenhirBox_goal _v
    
    let rec _menhir_run_001 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_068 x in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
    
    and _menhir_goto_closed_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState429 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState435 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState527 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState525 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState490 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState432 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState043 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_437 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_313 t in
        _menhir_goto_sequent _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_sequent : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState447 ->
            _menhir_run_448 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState440 ->
            _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState435 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState429 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_448 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_292 x in
        _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_goto_option_preceded_IFF_sequent__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, guard) = _menhir_stack in
        let MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, to_remove) = _menhir_stack in
        let MenhirCell1_list_sequent_ (_menhir_stack, _, to_match) = _menhir_stack in
        let MenhirCell1_RULE (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_new_goal_, new_goal) = (_endpos, _v) in
        let _v = _menhir_action_027 _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let r = _v in
            let _v = _menhir_action_091 r in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 423
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_292 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_304 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.RCURLY ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_327 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_339 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_346 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.IMPORT ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.FIXITY _v_0 ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState419
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.EOF ->
            _menhir_run_363 _menhir_stack MenhirState419
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState419
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _menhir_s = MenhirState419 in
            let _v = _menhir_action_018 () in
            _menhir_goto_attributes _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v _menhir_s _tok
        | _ ->
            _eRR 419
    
    and _menhir_run_269 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _startpos__1_ = _startpos in
        let _v = _menhir_action_010 () in
        _menhir_goto_accumulate _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_accumulate : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_accumulate (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState533
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.IO _v_1 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState533
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.CONSTANT _v_2 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState533
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
        | _ ->
            _eRR 533
    
    and _menhir_run_534 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let s = _v in
        let _v = _menhir_action_109 s in
        _menhir_goto_filename _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_filename : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_filename (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState538 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 538)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _v = _menhir_action_307 x in
            _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 537
    
    and _menhir_run_002 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_085 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_constant : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState533 ->
            _menhir_run_540 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState538 ->
            _menhir_run_540 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState425 ->
            _menhir_run_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState450 ->
            _menhir_run_451 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState366 ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState354 ->
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState328 ->
            _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState325 ->
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState322 ->
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState310 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState316 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState312 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState302 ->
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState292 ->
            _menhir_run_299 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState297 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState294 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState293 ->
            _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState398 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState290 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState286 ->
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState279 ->
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState452 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState274 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState277 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState527 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState525 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState490 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState432 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState429 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState435 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState043 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_540 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let c = _v in
        let _v = _menhir_action_108 c in
        _menhir_goto_filename _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_468 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_030 t in
            _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_114 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 468
    
    and _menhir_goto_clause_hd_closed_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_065 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState470 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 470)
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState472 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 472)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState474 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 474)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState476 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 476)
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState478 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 478)
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState480 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 480)
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState482 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 482)
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState484 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 484)
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState486 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 486)
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState488 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 488)
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_90 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_90 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState490 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 490)
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_100 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_100 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState492 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 492)
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_110 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_110 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState494 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 494)
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_120 ->
            let _endpos_122 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s, _startpos_l_, l) = (_endpos_122, _v_120, _startpos, _v) in
            let _v = _menhir_action_063 l s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_123 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_123 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState497 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 497)
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_133 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_133 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState499 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 499)
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_143 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_143 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState501 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 501)
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_153 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_153 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState503 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 503)
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_163 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_163 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState505 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 505)
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_173 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_173 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState507 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 507)
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_183 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_183 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState509 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 509)
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_193 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_193 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState511 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 511)
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_203 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v = _v_203 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState513 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 513)
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState515 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 515)
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState517 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 517)
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState519 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 519)
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState521 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 521)
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState523 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 523)
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState525 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 525)
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState527 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 527)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState529 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 529)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_body_, _startpos_body_, body) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_028 _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 469
    
    and _menhir_run_003 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_080 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_004 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
    
    and _menhir_run_005 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_084 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_006 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_089 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_007 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_077 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState008 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 8
    
    and _menhir_run_009 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_202 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_mixfix_SYMB : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState354 ->
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState460 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState430 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState293 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState274 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState281 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState271 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState008 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_355 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_111 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 355
    
    and _menhir_goto_fixity : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_f_, f) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_107 _endpos__2_ _startpos_f_ f in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 417
    
    and _menhir_run_224 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_087 s in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 224
    
    and _menhir_run_010 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_199 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_011 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_198 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_012 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_192 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_013 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_194 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_014 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_190 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_015 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_188 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_016 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_189 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_187 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState018 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 18
    
    and _menhir_run_019 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState019 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.RBRACKET ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PIPE ->
            _menhir_run_021 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 19
    
    and _menhir_run_020 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _endpos__1_ = _endpos in
        let _v = _menhir_action_164 () in
        _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_list_items : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_191 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_071 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_189 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_166 x xs in
        _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_021 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PIPE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState021 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 21
    
    and _menhir_run_022 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_082 c in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _menhir_s _tok
    
    and _menhir_run_023 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_066 x in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
    
    and _menhir_run_024 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_081 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_025 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_076 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_026 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_086 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_027 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_067 x in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
    
    and _menhir_run_028 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState028 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 28
    
    and _menhir_run_029 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_083 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_030 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_075 c in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _menhir_s _tok
    
    and _menhir_run_031 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_078 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_032 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_079 () in
        _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState039 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 39
    
    and _menhir_run_194 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_193 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_195 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_174 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState196
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState196
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState196
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState196
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState196
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_5 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState196
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.CONSTANT _v_6 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState196
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_203 s in
            _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 196
    
    and _menhir_run_197 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_184 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_198 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_182 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_199 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_204 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_200 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_173 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_201 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_181 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_202 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_175 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_203 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_177 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_204 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_178 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_205 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_176 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_206 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_179 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_207 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_183 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_208 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_180 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_run_209 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_191 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_210 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_186 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_211 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_195 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_212 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_197 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_213 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_185 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_214 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_200 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_215 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_201 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_216 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_088 () in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 216
    
    and _menhir_run_218 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_196 () in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_open_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_064 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_clause : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let c = _v in
        let _v = _menhir_action_090 c in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_head_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState425 ->
            _menhir_run_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState429 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState447 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState440 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState435 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState043 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState527 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState525 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState490 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState432 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_465 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState465
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState465
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState465
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState465
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState465
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState465
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | _ ->
            _eRR 465
    
    and _menhir_run_047 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_043 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState043
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState043
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState043
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState043
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState043
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState043
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.COLON | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 43
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState036
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState036
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState036
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState036
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState036
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState036
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 36
    
    and _menhir_run_451 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_452 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState451
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_170 () in
            _menhir_goto_loption_separated_nonempty_list_option_CONJ__pred_item__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _eRR 451
    
    and _menhir_run_452 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, _v) in
        let _menhir_s = MenhirState452 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 452
    
    and _menhir_run_274 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState274 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 274
    
    and _menhir_run_272 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_203 s in
        _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_loption_separated_nonempty_list_option_CONJ__pred_item__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_constant (_menhir_stack, _, c, _startpos_c_, _endpos_c_) = _menhir_stack in
        let MenhirCell1_PRED (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_298 _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let p = _v in
        let _v = _menhir_action_092 p in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_369 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState369
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState369
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.QDASH ->
            let _v_2 = _menhir_action_160 () in
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
        | _ ->
            _eRR 369
    
    and _menhir_run_271 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState271 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 271
    
    and _menhir_run_370 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_161 x xs in
        _menhir_goto_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_list_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState369 ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState366 ->
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState364 ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_367 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_CONSTRAINT, _menhir_box_program) _menhir_cell1_list_constant_ _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_list_constant_ (_menhir_stack, _, hyps) = _menhir_stack in
            let MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__5_, cl) = (_endpos, _v) in
            let _v = _menhir_action_097 _endpos__5_ _startpos__1_ cl hyps in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 367
    
    and _menhir_run_365 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_CONSTRAINT as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_list_constant_ (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.IO _v_0 ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState366
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState366
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState366
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _v_2 = _menhir_action_160 () in
                _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
            | _ ->
                _eRR 366)
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, cl) = (_endpos, _v) in
            let _v = _menhir_action_098 _endpos__3_ _startpos__1_ cl in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_357 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_110 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 357
    
    and _menhir_run_329 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState329
        | _ ->
            _eRR 329
    
    and _menhir_run_330 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let io = _v in
        let _v = _menhir_action_116 io in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_i_o (_menhir_stack, _menhir_s, _v) in
            _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState333
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_212 x in
            _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 333
    
    and _menhir_goto_nonempty_list_i_o_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState333 ->
            _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState329 ->
            _menhir_run_331 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_334 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_i_o -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_i_o (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_213 x xs in
        _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_331 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (l, _endpos__5_) = (_v, _endpos) in
        let _v = _menhir_action_205 _endpos__5_ _startpos__1_ c l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_095 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 409
    
    and _menhir_run_326 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_MODULE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_117 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_goto_ignored : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _endpos__2_) = (_startpos, _endpos) in
            let _v = _menhir_action_106 _endpos__2_ _startpos__1_ in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 415
    
    and _menhir_run_323 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_NAMESPACE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos, c, _endpos__3_) = (_endpos_1, _v, _endpos_1) in
            let _v = _menhir_action_099 _endpos__3_ _startpos__1_ c in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 323
    
    and _menhir_run_314 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos, _endpos) in
                let _menhir_s = MenhirState316 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.REPLACE ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.PI ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.NIL ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.NAME ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.IO _v ->
                    _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Elpi_lexer_config.Tokens.INDEX ->
                    _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.IF ->
                    _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.CUT ->
                    _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.CONSTANT _v ->
                    _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Elpi_lexer_config.Tokens.BEFORE ->
                    _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.AFTER ->
                    _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR 316)
            | _ ->
                _eRR 315)
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.RCURLY ->
            let name = _v in
            let _v = _menhir_action_316 name in
            _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR 314
    
    and _menhir_goto_subtrie : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_subtrie (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState312 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 312)
        | Elpi_lexer_config.Tokens.RCURLY ->
            let x = _v in
            let _v = _menhir_action_309 x in
            _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 311
    
    and _menhir_goto_separated_nonempty_list_CONJ_subtrie_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState310 ->
            _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState316 ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState312 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_319 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_324 c l in
        let l = _v in
        let _v = _menhir_action_315 l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_100 _endpos__3_ _startpos__1_ s in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 306
    
    and _menhir_run_317 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, prefix, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_317 l prefix in
        _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_313 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_subtrie (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_310 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_308 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos, _endpos) in
                let _menhir_s = MenhirState310 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.REPLACE ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.PI ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.NIL ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.NAME ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.IO _v ->
                    _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Elpi_lexer_config.Tokens.INDEX ->
                    _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.IF ->
                    _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.CUT ->
                    _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.CONSTANT _v ->
                    _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Elpi_lexer_config.Tokens.BEFORE ->
                    _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Elpi_lexer_config.Tokens.AFTER ->
                    _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR 310)
            | _ ->
                _eRR 309)
        | _ ->
            _eRR 308
    
    and _menhir_run_303 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_SIG -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_118 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_299 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let c = _v in
        let _v = _menhir_action_005 c in
        _menhir_goto_abbrevform _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_abbrevform : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_abbrevform (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState300
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState300
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | _ ->
            _eRR 300
    
    and _menhir_run_297 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState297
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState297
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_210 x in
            _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 297
    
    and _menhir_goto_nonempty_list_constant_ : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState297 ->
            _menhir_run_298 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState294 ->
            _menhir_run_295 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_298 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_211 x xs in
        _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_295 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, hd, _, _) = _menhir_stack in
        let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let args = _v in
        let _v = _menhir_action_006 args hd in
        _menhir_goto_abbrevform _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_294 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState294
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState294
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | _ ->
            _eRR 294
    
    and _menhir_run_289 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState290 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 290)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_305 x in
            _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 289
    
    and _menhir_goto_separated_nonempty_list_CONJ_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState426 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState398 ->
            _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState360 ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_348 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_342 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState290 ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState270 ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_427 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState427
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState427
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | _ ->
            _eRR 427
    
    and _menhir_run_399 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_CLOSED -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_124 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_361 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState361
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState361
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_119 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 361
    
    and _menhir_run_348 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            _menhir_run_349 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState348
        | _ ->
            _eRR 348
    
    and _menhir_run_349 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState350 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.TYPE ->
                _menhir_run_349 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 350)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_158 () in
            _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s
        | _ ->
            _eRR 349
    
    and _menhir_goto_kind_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState348 ->
            _menhir_run_352 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState350 ->
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_352 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
        let MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_k_, k) = (_endpos, _v) in
        let _v = _menhir_action_157 _endpos_k_ _startpos__1_ k names in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let t = _v in
        let _v = _menhir_action_094 t in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_351 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_t_, t, hd) = (_endpos, _v, ()) in
        let _v = _menhir_action_159 _endpos_hd_ _startpos_hd_ hd t in
        _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s
    
    and _menhir_run_342 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState342
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState342
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _ = _menhir_action_295 () in
            _menhir_goto_option_type_term_ _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 342
    
    and _menhir_goto_option_type_term_ : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, l, _) = _menhir_stack in
        let MenhirCell1_LOCAL (_menhir_stack, _menhir_s) = _menhir_stack in
        let _v = _menhir_action_105 l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_340 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_LOCALKIND -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_121 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_291 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_306 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_273 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState273
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.CONSTANT _v_1 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState273
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_122 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 273
    
    and _menhir_run_285 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_022 c in
        _menhir_goto_atype_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _menhir_s _tok
    
    and _menhir_goto_atype_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState286
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.IO _v_1 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState286
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.CONSTANT _v_2 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState286
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_206 x in
            _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 286
    
    and _menhir_run_280 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_021 c in
        _menhir_goto_atype_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _menhir_s _tok
    
    and _menhir_run_281 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState281 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 281
    
    and _menhir_goto_nonempty_list_atype_term_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState286 ->
            _menhir_run_287 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState279 ->
            _menhir_run_284 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_287 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_atype_term -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_atype_term (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_207 x xs in
        _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_284 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_args_, args) = (_endpos, _v) in
        let _v = _menhir_action_327 _endpos_hd_ _startpos_hd_ args hd in
        _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_args_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_goto_type_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState452 ->
            _menhir_run_453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_362 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_343 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_282 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState277 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState274 ->
            _menhir_run_275 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_453 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_IO_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ ->
            let MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, io) = _menhir_stack in
            let (_endpos_ty_, ty) = (_endpos, _v) in
            let _v = _menhir_action_299 io ty in
            let _endpos = _endpos_ty_ in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.CONJ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let x = () in
                let _v = _menhir_action_284 x in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO_COLON _ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _v = _menhir_action_283 () in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FULLSTOP ->
                let (_endpos_x_, x) = (_endpos, _v) in
                let _v = _menhir_action_311 x in
                _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR 453
    
    and _menhir_run_277 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_type_term -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState277 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 277
    
    and _menhir_goto_option_CONJ_ : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let _menhir_stack = MenhirCell0_option_CONJ_ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_452 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState457
        | _ ->
            _eRR 457
    
    and _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState457 ->
            _menhir_run_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState451 ->
            _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_458 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_option_CONJ_ (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_pred_item (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_312 x xs in
        _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s
    
    and _menhir_run_454 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_171 x in
        _menhir_goto_loption_separated_nonempty_list_option_CONJ__pred_item__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v
    
    and _menhir_run_428 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _, _startpos__2_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_325 _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let t = _v in
            let _v = _menhir_action_093 t in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 428
    
    and _menhir_run_362 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_120 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 362
    
    and _menhir_run_343 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _ = _menhir_action_296 x in
            _menhir_goto_option_type_term_ _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 343
    
    and _menhir_run_301 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_abbrevform (_menhir_stack, _, a) = _menhir_stack in
            let MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_330 _endpos_t_ _startpos__1_ a t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let a = _v in
            let _v = _menhir_action_101 a in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 301
    
    and _menhir_run_288 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_123 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 288
    
    and _menhir_run_282 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_023 t in
            _menhir_goto_atype_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 282
    
    and _menhir_run_278 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_type_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_328 _endpos_hd_ _startpos_hd_ hd t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_hd_ _v _menhir_s _tok
        | _ ->
            _eRR 278
    
    and _menhir_run_275 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_329 t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 275
    
    and _menhir_run_279 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_280 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState279
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.IO _v_1 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState279
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.CONSTANT _v_2 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState279
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_326 c in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _menhir_s _tok
        | _ ->
            _eRR 279
    
    and _menhir_run_117 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState118 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 118)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_114 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 117
    
    and _menhir_run_051 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState051
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.COLON | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_114 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 51
    
    and _menhir_run_038 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState038 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 38
    
    and _menhir_run_048 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_114 t in
        _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_separated_nonempty_list_CONJ_filename_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState538 ->
            _menhir_run_539 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState533 ->
            _menhir_run_535 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_539 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_filename (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_308 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_535 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_accumulate -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_accumulate (_menhir_stack, _menhir_s, ext, _startpos_ext_) = _menhir_stack in
        let (_endpos__3_, l) = (_endpos, _v) in
        let _v = _menhir_action_104 _endpos__3_ _startpos_ext_ ext l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_270 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState270 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 270
    
    and _menhir_run_292 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState292 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState293 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.SLASH ->
                _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QDASH ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.OR ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MOD ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSs ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSr ->
                _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSi ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUS ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IS ->
                _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
                _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
                _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
                _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
                _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
                _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
                _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
                _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
                _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
                _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
                _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
                _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
                _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
                _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.EQ2 ->
                _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.EQ ->
                _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.DIV ->
                _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.DARROW ->
                _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CONS ->
                _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONJ2 ->
                _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONJ ->
                _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 293)
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 292
    
    and _menhir_run_302 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState302 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 302
    
    and _menhir_run_304 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState304 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 304
    
    and _menhir_run_321 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_103 _endpos__1_ _startpos__1_ in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_322 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState322 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 322
    
    and _menhir_run_325 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState325 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 325
    
    and _menhir_run_327 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState328 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 328)
        | _ ->
            _eRR 327
    
    and _menhir_run_335 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState335 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 335
    
    and _menhir_run_339 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState339 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 339
    
    and _menhir_run_341 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOCAL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState341 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 341
    
    and _menhir_run_346 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_102 _endpos__1_ _startpos__1_ in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_347 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState347 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 347
    
    and _menhir_run_353 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _startpos__1_ = _startpos in
        let _v = _menhir_action_008 () in
        _menhir_goto_accumulate _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_354 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FIXITY (_menhir_stack, _menhir_s, _v, _startpos) in
        let _menhir_s = MenhirState354 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 354
    
    and _menhir_run_359 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
        let _v = _menhir_action_019 () in
        _menhir_goto_attributes _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_attributes : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_attributes (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            let _menhir_s = MenhirState425 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _menhir_s = MenhirState426 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 426)
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.RULE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RULE (_menhir_stack, MenhirState425, _startpos_4) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_6 ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState429
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState429
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.IO _v_8 ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState429
            | Elpi_lexer_config.Tokens.INTEGER _v_9 ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState429
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.FLOAT _v_10 ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState429
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.CONSTANT _v_11 ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 MenhirState429
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState429
            | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
                let _v_12 = _menhir_action_162 () in
                _menhir_run_438 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_5 _v_12 MenhirState429 _tok
            | _ ->
                _eRR 429)
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.PRED ->
            let _menhir_s = MenhirState425 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_PRED (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState450 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 450)
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_s = MenhirState425 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState460 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SLASH ->
                _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.QDASH ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.OR ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MOD ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSs ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSr ->
                _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUSi ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.MINUS ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IS ->
                _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
                _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
                _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
                _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
                _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
                _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
                _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
                _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
                _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
                _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
                _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
                _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
                _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
                _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.EQ2 ->
                _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.EQ ->
                _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.DIV ->
                _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.DARROW ->
                _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CONS ->
                _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONJ2 ->
                _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONJ ->
                _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 460)
        | Elpi_lexer_config.Tokens.IO _v_37 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_37 MenhirState425
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_38 ->
            let (_v, _menhir_s) = (_v_38, MenhirState425) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState463 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 463)
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_48 MenhirState425
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | _ ->
            _eRR 425
    
    and _menhir_run_430 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState430 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            _menhir_run_202 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_214 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 430
    
    and _menhir_run_438 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list_sequent_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState439 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 439)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v = _menhir_action_289 () in
            _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.PIPE ->
            let _menhir_s = MenhirState444 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 444)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let _v = _menhir_action_293 () in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_option_preceded_PIPE_term__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IFF ->
            let _menhir_s = MenhirState447 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 447)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_291 () in
            _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_360 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState360 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 360
    
    and _menhir_run_364 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.QDASH ->
            let _v = _menhir_action_160 () in
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState364 _tok
        | _ ->
            _eRR 364
    
    and _menhir_run_372 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState372 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 372
    
    and _menhir_run_373 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_015 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 373
    
    and _menhir_goto_attribute : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_attribute (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState396 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_375 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_377 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.EXTERNAL ->
                _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 396)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_303 x in
            _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 395
    
    and _menhir_run_375 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_012 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 375
    
    and _menhir_run_377 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INDEX (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState378 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 378)
        | _ ->
            _eRR 377
    
    and _menhir_run_379 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let i = _v in
        let _v = _menhir_action_126 i in
        _menhir_goto_indexing _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_indexing : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState385
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_214 x in
            _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 385
    
    and _menhir_run_380 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _v = _menhir_action_125 () in
        _menhir_goto_indexing _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_nonempty_list_indexing_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState385 ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState378 ->
            _menhir_run_381 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_386 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_indexing -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_indexing (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_215 x xs in
        _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_381 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_nonempty_list_indexing_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RPAREN (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_1, _v_0) in
            let _v = _menhir_action_286 x in
            _menhir_goto_option_STRING_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.COLON | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_285 () in
            _menhir_goto_option_STRING_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 382
    
    and _menhir_goto_option_STRING_ : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_nonempty_list_indexing_ _menhir_cell0_RPAREN -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_RPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_indexing_ (_menhir_stack, _, l) = _menhir_stack in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_INDEX (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (_endpos_o_, o) = (_endpos, _v) in
        let _v = _menhir_action_017 l o in
        _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_o_ _v _menhir_s _tok
    
    and _menhir_run_387 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_011 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 387
    
    and _menhir_run_389 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _endpos__1_ = _endpos in
        let _v = _menhir_action_016 () in
        _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_390 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_014 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 390
    
    and _menhir_run_392 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_013 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 392
    
    and _menhir_goto_separated_nonempty_list_COLON_attribute_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState396 ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState372 ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_397 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_attribute (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_304 x xs in
        _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_394 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_020 l in
        _menhir_goto_attributes _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_398 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState398 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 398
    
    and _menhir_run_400 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _startpos__1_ = _startpos in
        let _v = _menhir_action_009 () in
        _menhir_goto_accumulate _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_401 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _startpos__1_ = _startpos in
        let _v = _menhir_action_007 () in
        _menhir_goto_accumulate _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_440 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState440
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState440
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState440
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState440
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState440
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState440
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState440
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let x = _v in
            let _v = _menhir_action_216 x in
            _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 440
    
    and _menhir_goto_nonempty_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState439 ->
            _menhir_run_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState440 ->
            _menhir_run_441 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_442 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_290 x in
        _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
    
    and _menhir_run_441 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_217 x xs in
        _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_435 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState435
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState435
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState435
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState435
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState435
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState435
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v_6 = _menhir_action_162 () in
            _menhir_run_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_6 _tok
        | _ ->
            _eRR 435
    
    and _menhir_run_436 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_163 x xs in
        _menhir_goto_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState429 ->
            _menhir_run_438 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState435 ->
            _menhir_run_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_431 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState432 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 432)
        | Elpi_lexer_config.Tokens.ACCUMULATE | Elpi_lexer_config.Tokens.ACCUM_SIG | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.CLOSED | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CONSTRAINT | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.EXPORTDEF | Elpi_lexer_config.Tokens.EXTERNAL | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FIXITY _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IMPORT | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.KIND | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LOCAL | Elpi_lexer_config.Tokens.LOCALKIND | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MACRO | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.MODE | Elpi_lexer_config.Tokens.MODULE | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NAMESPACE | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SHORTEN | Elpi_lexer_config.Tokens.SIG | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.TYPE | Elpi_lexer_config.Tokens.TYPEABBREV | Elpi_lexer_config.Tokens.USEONLY | Elpi_lexer_config.Tokens.USE_SIG | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_320 t in
            _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState529 ->
            _menhir_run_530 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState527 ->
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState525 ->
            _menhir_run_526 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState523 ->
            _menhir_run_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState521 ->
            _menhir_run_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState519 ->
            _menhir_run_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState515 ->
            _menhir_run_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState511 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState509 ->
            _menhir_run_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState507 ->
            _menhir_run_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState505 ->
            _menhir_run_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState503 ->
            _menhir_run_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState501 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState499 ->
            _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState490 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState486 ->
            _menhir_run_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState484 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState482 ->
            _menhir_run_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState474 ->
            _menhir_run_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState472 ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState470 ->
            _menhir_run_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState463 ->
            _menhir_run_464 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_461 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState444 ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState432 ->
            _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_119 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_530 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_056 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 530
    
    and _menhir_run_058 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState058 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 58
    
    and _menhir_run_074 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState074 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 74
    
    and _menhir_run_076 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState076 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 76
    
    and _menhir_run_082 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState082 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 82
    
    and _menhir_run_084 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState084 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 84
    
    and _menhir_run_086 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState086 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 86
    
    and _menhir_run_088 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState088 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 88
    
    and _menhir_run_078 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState078 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 78
    
    and _menhir_run_090 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState090 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 90
    
    and _menhir_run_060 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState060 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 60
    
    and _menhir_run_041 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_250 l s in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_092 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState092 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 92
    
    and _menhir_run_062 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState062 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 62
    
    and _menhir_run_066 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState066 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 66
    
    and _menhir_run_098 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState098 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 98
    
    and _menhir_run_100 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState100 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 100
    
    and _menhir_run_094 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState094 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 94
    
    and _menhir_run_068 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState068 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 68
    
    and _menhir_run_070 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState070 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 70
    
    and _menhir_run_064 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState064 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 64
    
    and _menhir_run_102 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState102 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 102
    
    and _menhir_run_104 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState104 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 104
    
    and _menhir_run_080 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState080 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 80
    
    and _menhir_run_106 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState106 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 106
    
    and _menhir_run_096 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState096 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 96
    
    and _menhir_run_112 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState112 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 112
    
    and _menhir_run_528 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_061 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 528
    
    and _menhir_run_108 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState108 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 108
    
    and _menhir_run_110 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState110 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 110
    
    and _menhir_run_526 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_060 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 526
    
    and _menhir_run_524 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_045 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 524
    
    and _menhir_run_522 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_057 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 522
    
    and _menhir_run_520 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_055 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 520
    
    and _menhir_run_518 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_046 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 518
    
    and _menhir_run_516 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_051 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 516
    
    and _menhir_run_514 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_040 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 514
    
    and _menhir_run_512 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_043 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 512
    
    and _menhir_run_510 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_039 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 510
    
    and _menhir_run_508 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_036 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 508
    
    and _menhir_run_506 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_038 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 506
    
    and _menhir_run_504 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_037 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 504
    
    and _menhir_run_502 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_035 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 502
    
    and _menhir_run_500 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_041 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 500
    
    and _menhir_run_498 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_033 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 498
    
    and _menhir_run_495 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_042 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 495
    
    and _menhir_run_493 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_044 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 493
    
    and _menhir_run_491 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_034 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 491
    
    and _menhir_run_489 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_053 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 489
    
    and _menhir_run_487 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_047 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 487
    
    and _menhir_run_485 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_049 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 485
    
    and _menhir_run_483 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_048 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 483
    
    and _menhir_run_481 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_050 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 481
    
    and _menhir_run_479 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_054 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 479
    
    and _menhir_run_477 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_052 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 477
    
    and _menhir_run_072 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState072 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 72
    
    and _menhir_run_475 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_058 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 475
    
    and _menhir_run_473 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_059 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 473
    
    and _menhir_run_471 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _, l, _startpos_l_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_029 _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 471
    
    and _menhir_run_056 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState056 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 56
    
    and _menhir_run_114 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState114 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 114
    
    and _menhir_run_464 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_062 r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 464
    
    and _menhir_run_461 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_031 t in
                _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_115 t in
                _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR 462)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 461
    
    and _menhir_run_445 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let x = _v in
            let _v = _menhir_action_294 x in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 445
    
    and _menhir_run_433 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_closed_term _menhir_cell0_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_closed_term (_menhir_stack, _, c, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (t, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_314 c t in
            _menhir_goto_sequent _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 433
    
    and _menhir_run_338 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _, m, _, _) = _menhir_stack in
            let MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_172 _endpos_b_ _startpos__1_ b m in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_096 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 338
    
    and _menhir_run_336 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState337 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 337)
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_9 ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_10 ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_11 ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_12 ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_13 ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_14 ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_15 ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_16 ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_17 ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_18 ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_19 ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_20 ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_21 ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_21
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 336
    
    and _menhir_run_226 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_goal) _menhir_state -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_113 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EOF ->
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_14, _startpos, _v) in
            let _v = _menhir_action_112 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 226
    
    and _menhir_run_222 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_term as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term (_menhir_stack, _, t, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (c, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_070 c t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 222
    
    and _menhir_run_219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_115 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState221 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 221)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 219
    
    and _menhir_run_192 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LCURLY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_1, _v) in
            let _v = _menhir_action_073 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_14 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 192
    
    and _menhir_run_119 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_constant _menhir_cell0_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_026 b t in
            let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_322 t in
            _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 119
    
    and _menhir_goto_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState184 ->
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_185 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (xs, _endpos__4_) = (_v, _endpos_0) in
            let _v = _menhir_action_168 x xs in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 185
    
    and _menhir_run_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState123 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 123
    
    and _menhir_run_125 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState125 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 125
    
    and _menhir_goto_list_items_tail : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_072 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_188 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_169 x xs in
        _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_180 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState180 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 180
    
    and _menhir_run_139 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState139 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 139
    
    and _menhir_run_141 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState141 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 141
    
    and _menhir_run_143 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState143 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 143
    
    and _menhir_run_149 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState149 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 149
    
    and _menhir_run_151 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState151 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 151
    
    and _menhir_run_153 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState153 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 153
    
    and _menhir_run_155 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState155 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 155
    
    and _menhir_run_145 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState145 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 145
    
    and _menhir_run_157 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState157 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 157
    
    and _menhir_run_127 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState127 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 127
    
    and _menhir_run_034 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_282 l s in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_321 t in
        _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_159 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState159 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 159
    
    and _menhir_run_129 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState129 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 129
    
    and _menhir_run_133 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState133 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 133
    
    and _menhir_run_165 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState165 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 165
    
    and _menhir_run_167 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState167 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 167
    
    and _menhir_run_161 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState161 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 161
    
    and _menhir_run_135 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState135 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 135
    
    and _menhir_run_137 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState137 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 137
    
    and _menhir_run_131 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState131 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 131
    
    and _menhir_run_169 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState169 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 169
    
    and _menhir_run_171 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState171 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 171
    
    and _menhir_run_147 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState147 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 147
    
    and _menhir_run_173 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState173 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 173
    
    and _menhir_run_163 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState163 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 163
    
    and _menhir_run_175 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState175 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 175
    
    and _menhir_run_177 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState177 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 177
    
    and _menhir_run_182 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (x, _endpos__2_) = (_v, _endpos_0) in
            let _v = _menhir_action_165 x in
            _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState184 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 184)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_14 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_15 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_16 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_17 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_18 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_19 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_20 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState187 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.SIGMA ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.RBRACKET ->
                _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.QUOTED _v ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.PIPE ->
                _menhir_run_021 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.PI ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NIL ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IO _v ->
                _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FRESHUV ->
                _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.FLOAT _v ->
                _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.CUT ->
                _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR 187)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 182
    
    and _menhir_run_181 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_277 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 181
    
    and _menhir_run_178 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_275 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 178
    
    and _menhir_run_176 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_279 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 176
    
    and _menhir_run_174 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_276 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 174
    
    and _menhir_run_172 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_265 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 172
    
    and _menhir_run_170 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_270 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 170
    
    and _menhir_run_168 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_257 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 168
    
    and _menhir_run_166 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_256 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 166
    
    and _menhir_run_164 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_264 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 164
    
    and _menhir_run_162 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_255 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 162
    
    and _menhir_run_160 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_252 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 160
    
    and _menhir_run_158 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_263 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 158
    
    and _menhir_run_156 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_272 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 156
    
    and _menhir_run_154 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_266 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 154
    
    and _menhir_run_152 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_268 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 152
    
    and _menhir_run_150 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_267 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 150
    
    and _menhir_run_148 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_274 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 148
    
    and _menhir_run_146 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_253 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 146
    
    and _menhir_run_144 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_269 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 144
    
    and _menhir_run_142 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_273 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 142
    
    and _menhir_run_140 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_271 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 140
    
    and _menhir_run_138 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_262 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 138
    
    and _menhir_run_136 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_258 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 136
    
    and _menhir_run_134 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_254 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 134
    
    and _menhir_run_132 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_259 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 132
    
    and _menhir_run_130 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_260 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 130
    
    and _menhir_run_128 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_261 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 128
    
    and _menhir_run_126 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_278 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 126
    
    and _menhir_run_124 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_280 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 124
    
    and _menhir_run_122 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PIPE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_PIPE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_167 x in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 122
    
    and _menhir_run_033 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_281 r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 33
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_244 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 115
    
    and _menhir_run_113 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_242 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 113
    
    and _menhir_run_111 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_247 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 111
    
    and _menhir_run_109 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_246 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 109
    
    and _menhir_run_107 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_243 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 107
    
    and _menhir_run_105 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_232 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 105
    
    and _menhir_run_103 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_237 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 103
    
    and _menhir_run_101 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_224 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 101
    
    and _menhir_run_099 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_223 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 99
    
    and _menhir_run_097 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_231 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 97
    
    and _menhir_run_095 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_222 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 95
    
    and _menhir_run_093 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_219 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 93
    
    and _menhir_run_091 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_230 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 91
    
    and _menhir_run_089 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_239 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 89
    
    and _menhir_run_087 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_233 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 87
    
    and _menhir_run_085 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_235 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 85
    
    and _menhir_run_083 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_234 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 83
    
    and _menhir_run_081 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_241 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 81
    
    and _menhir_run_079 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_220 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 79
    
    and _menhir_run_077 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_236 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 77
    
    and _menhir_run_075 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_240 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 75
    
    and _menhir_run_073 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_238 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 73
    
    and _menhir_run_071 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_229 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 71
    
    and _menhir_run_069 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_225 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 69
    
    and _menhir_run_067 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_221 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 67
    
    and _menhir_run_065 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_226 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 65
    
    and _menhir_run_063 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_227 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 63
    
    and _menhir_run_061 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_228 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 61
    
    and _menhir_run_059 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_245 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 59
    
    and _menhir_run_057 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_248 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 57
    
    and _menhir_run_055 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos_bind_, _endpos_bind_) = _menhir_stack in
            let (_endpos_b_, b, bind) = (_endpos, _v, ()) in
            let _v = _menhir_action_024 _endpos_bind_ _startpos_bind_ b bind in
            _menhir_goto_binder_body _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _v _menhir_s _tok
        | _ ->
            _eRR 55
    
    and _menhir_goto_binder_body : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState051 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState466 ->
            _menhir_run_046 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_046 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState044 ->
            _menhir_run_046 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_052 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_025 b t in
        let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_319 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_046 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_288 x in
        _menhir_goto_option_binder_body_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
    
    and _menhir_goto_option_binder_body_ : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState466 ->
            _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState037 ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState044 ->
            _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_467 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_032 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_116 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_251 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_045 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_218 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_040 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_249 r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 40
    
    and _menhir_run_120 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_323 t in
        _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_053 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_049 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState049
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.QUOTED _v_1 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState049
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.IO _v_2 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState049
        | Elpi_lexer_config.Tokens.INTEGER _v_3 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState049
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.FLOAT _v_4 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState049
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.CONSTANT _v_5 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState049
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let x = _v in
            let _v = _menhir_action_208 x in
            _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 49
    
    and _menhir_goto_nonempty_list_closed_term_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState465 ->
            _menhir_run_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState043 ->
            _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_466 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState466
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v_0 = _menhir_action_287 () in
            _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR 466
    
    and _menhir_run_050 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_closed_term (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_209 x xs in
        _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_044 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState044
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v_0 = _menhir_action_287 () in
            _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_037 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v_0 = _menhir_action_287 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR 37
    
    let _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState000 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.SIGMA ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.PI ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NIL ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IO _v ->
            _menhir_run_022 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            _menhir_run_023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FRESHUV ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.CUT ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR 0
    
    let _menhir_goto_infix_SYMB : type  ttv_stack. ttv_stack -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _v ->
        MenhirBox_infix_SYMB _v
    
    let _menhir_run_230 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_156 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.SLASH ->
            let _v = _menhir_action_153 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.QDASH ->
            let _v = _menhir_action_152 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.OR ->
            let _v = _menhir_action_146 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MOD ->
            let _v = _menhir_action_148 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _v = _menhir_action_144 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _v = _menhir_action_142 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _v = _menhir_action_143 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUS ->
            let _v = _menhir_action_141 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.IS ->
            let _v = _menhir_action_147 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let s = _v in
            let _v = _menhir_action_128 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let s = _v in
            let _v = _menhir_action_138 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let s = _v in
            let _v = _menhir_action_136 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let s = _v in
            let _v = _menhir_action_127 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let s = _v in
            let _v = _menhir_action_135 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let s = _v in
            let _v = _menhir_action_129 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let s = _v in
            let _v = _menhir_action_131 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let s = _v in
            let _v = _menhir_action_132 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let s = _v in
            let _v = _menhir_action_130 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let s = _v in
            let _v = _menhir_action_133 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let s = _v in
            let _v = _menhir_action_137 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let s = _v in
            let _v = _menhir_action_134 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _v = _menhir_action_145 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ ->
            let _v = _menhir_action_140 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _v = _menhir_action_149 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DARROW ->
            let _v = _menhir_action_151 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONS ->
            let _v = _menhir_action_139 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _v = _menhir_action_154 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ ->
            let _v = _menhir_action_155 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.ARROW ->
            let _v = _menhir_action_150 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | _ ->
            _eRR 230
    
    let _menhir_run_262 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_postfix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let s = _v in
            let _v = _menhir_action_297 s in
            MenhirBox_postfix_SYMB _v
        | _ ->
            _eRR 262
    
    let _menhir_run_265 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_prefix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let s = _v in
            let _v = _menhir_action_300 s in
            MenhirBox_prefix_SYMB _v
        | _ ->
            _eRR 265
    
    let _menhir_run_268 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState268 in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            _menhir_run_269 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_292 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_304 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.RCURLY ->
            _menhir_run_321 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_327 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_339 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_346 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.IMPORT ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.FIXITY _v ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            _menhir_run_359 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.EOF ->
            _menhir_run_363 _menhir_stack _menhir_s
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_018 () in
            _menhir_goto_attributes _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v _menhir_s _tok
        | _ ->
            _eRR 268
    
  end
  
  let program =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_program v = _menhir_run_268 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let prefix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_prefix_SYMB v = _menhir_run_265 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let postfix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_postfix_SYMB v = _menhir_run_262 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let infix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_infix_SYMB v = _menhir_run_230 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let goal =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_goal v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
